// REM  MACHINERY INFORMATION MANAGEMENT OPEN SYSTEM ALLIANCE  (MIMOSA)
// REM      COMMON, RELATIONAL INFORMATION SCHEMA (CRIS)
// REM 
// REM  V1.1 Production Relational Database Schema -- 82 Tables
// REM  CRIS_V11.SQL
// REM
// REM  Last Updated On: 03-Sep-1997
// REM        Tested On: Sybase SQL Anywhere Database Engine Version 5.0
// REM
// REM  The Machinery Information Management Open Systems Alliance has 
// REM  developed Version 1.1 of a common, relational information schema
// REM  to facilitate the exchanging of machinery information.  This schema
// REM  is known as CRIS.  CRIS allows machinery information providers to
// REM  map their data into a common set of tables and columns for the
// REM  purpose of building MIMOSA Export Data (MED) files for import or
// REM  export, creating a MIMOSA Programmatic Database Interface (PDI)
// REM  to allow ODBC read-access to the database, or for future MIMOSA
// REM  object-oriented extensions called the Common Object Oriented Protocol.
// REM  
// REM  This version of the schema utilizes the following nomenclature:
// REM
// REM		  
// REM   DATA TYPES
// REM   ==========
// REM   SMALLINT := 2-byte unsigned integer (-32,676 to 32,675)
// REM 
// REM   INTEGER := 4-byte unsigned integer (-2147483648 to 2147483647)
// REM 
// REM   DOUBLE := 8-byte floating point number
// REM 
// REM   CHAR(length) := fixed-length character string with exactly length 
// REM                  	characters
// REM 
// REM   VARCHAR(maxlength) := variable-length character string with up to 
// REM                  	maxlength characters
// REM 
// REM   LONG BINARY := variable-length binary data of unlimited length except
// REM                  	as constrained by systems environment 
// REM 
// REM   TERMS
// REM   =====
// REM   column NOT NULL := a value must be specified for the column when 
// REM                  	inserting a row and cannot be updated to be 
// REM				"NULL" (empty)
// REM 
// REM   CHECK (column in (valid_list)) := values for the column must exist 
// REM				in the valid_list
// REM 
// REM   PRIMARY KEY(column_list) := column(s) specified create a unique 
// REM				identifier for each row in the table
// REM 
// REM   FOREIGN KEY {name} (curr_column_list) REFERENCES ref_table 
// REM				(ref_column_list) := column(s) in the 
// REM				curr_column_list in the current table are linked
// REM 				back to ref_table's primary key columns or 
// REM				unique index columns ref_column_list.  An 
// REM				optional name for the foreign key may be 
// REM				specified to differentiate between multiple 
// REM				foreign keys which reference the same ref_table
// REM
// REM 
// REM DISCLAIMER OF WARRANTIES AND TECHNICAL SUPPORT
// REM ==============================================
// REM 
// REM This schema is provided to you free of charge, and on an "AS IS" 
// REM basis, without any technical support or warranty of any kind from 
// REM MIMOSA including, without limitation, a warranty of merchantability, 
// REM fitness for a particular purpose and non-infringement.  Some states 
// REM do not allow the exclusion of implied warranties, so the above 
// REM exclusion may not apply to you.  You may also have other legal rights 
// REM which vary from state to state. 
// REM 
// REM
// REM LIMITATION OF DAMAGES
// REM =====================
// REM 
// REM MIMOSA shall not be liable for any indirect, special, incidental or 
// REM consequential damages or loss (including damages for loss of 
// REM business, loss of profits, or the like), whether based on breach of 
// REM contract, tort (including negligence), product liability or otherwise, 
// REM even if MIMOSA or its representatives have been advised of the 
// REM possibility of such damages. Some states do not allow the limitation 
// REM or exclusion of liability for incidental or consequential damages, so 
// REM this limitation or exclusion may not apply to you. The limited 
// REM warranty, exclusive remedies and limited liability set forth above 
// REM are fundamental elements of the basis of the bargain between MIMOSA 
// REM and you. You agree that MIMOSA will not be able to provide this 
// REM schema and any associated Software on an economic basis without such 
// REM limitations.
// REM  
// REM 

DROP TABLE mloc_ulist_sp_cpb;
DROP TABLE mloc_ulist_sp_time;
DROP TABLE mloc_ulist_sp_fft;
DROP TABLE mloc_ulist_sp_ampl;
DROP TABLE sp_cpb_setup;
DROP TABLE sp_time_setup;
DROP TABLE sp_fft_setup;
DROP TABLE sp_ampl_setup;
DROP TABLE sp_cpb_data;
DROP TABLE sp_time_data;
DROP TABLE sp_fft_data;
DROP TABLE window_type;
DROP TABLE sp_ampl_alarm;
DROP TABLE mloc_spa_alrm_rg;
DROP TABLE sp_ampl_data;
DROP TABLE post_scaling_type;
DROP TABLE src_detect_type;
DROP TABLE ave_synch_type;
DROP TABLE ave_weight_type;
DROP TABLE average_type;
DROP TABLE sp_stream_block;
DROP TABLE sp_stream;
DROP TABLE sp_blk_num_data;
DROP TABLE sp_num_dat_type;
DROP TABLE signal_proc_blk;
DROP TABLE signal_proc_type;
DROP TABLE mevent_num_alarm;
DROP TABLE mloc_num_alrm_rg;
DROP TABLE alarm_type;
DROP TABLE alarm_severity;
DROP TABLE mevent_chr_data;
DROP TABLE mevent_num_data;
DROP TABLE meas_event_rem;
DROP TABLE meas_event_assoc;
DROP TABLE meas_event;
DROP TABLE data_qual_type;
DROP TABLE transducer;
DROP TABLE data_source;
DROP TABLE mloc_unit_list;
DROP TABLE meas_loc_list;
DROP TABLE ordered_list;
DROP TABLE meas_location;
DROP TABLE tr_axis_dir_type;
DROP TABLE trans_type;
DROP TABLE data_source_type;
DROP TABLE meas_loc_type;
DROP TABLE asset_owner;
DROP TABLE asset_on_segment;
DROP TABLE asset_event;
DROP TABLE asset_chr_data;
DROP TABLE asset_num_data;
DROP TABLE asset_output;
DROP TABLE asset_input;
DROP TABLE asset_child;
DROP TABLE asset;
DROP TABLE model_chr_data;
DROP TABLE model_num_data;
DROP TABLE as_chr_dat_type;
DROP TABLE as_num_dat_type;
DROP TABLE model_child;
DROP TABLE model;
DROP TABLE asset_type_child;
DROP TABLE asset_type;
DROP TABLE segment_event;
DROP TABLE sg_as_event_type;
DROP TABLE segment_chr_data;
DROP TABLE segment_num_data;
DROP TABLE sg_chr_dat_type;
DROP TABLE sg_num_dat_type;
DROP TABLE eng_unit_enum;
DROP TABLE eng_unit_type;
DROP TABLE ref_unit_type;
DROP TABLE segment_output;
DROP TABLE segment_input;
DROP TABLE segment_child;
DROP TABLE segment;
DROP TABLE segment_type_child;
DROP TABLE segment_type;
DROP TABLE manufacturer;
DROP TABLE site_database;
DROP TABLE site;
DROP TABLE row_status_type;

// REM #12 -- Row Status Type Code
// REM
// REM   The row status code is a foreign key in every other table to
// REM   define the status of the row.  These codes will not change.
// REM   The entries will include the following:
// REM
// REM                        1 = Active Row
// REM                        2 = Inactive Row
// REM                        3 = Soft Deleted Row
// REM
// REM   NOTE: MIMOSA populates and maintains this table.
// REM         No user-defined entries are supported.
// REM
// REM   NOTE: The gmt_last_updated column is in every table to store the
// REM         the date the row was inserted or updated.
// REM
// REM   NOTE: All gmt fields are in Greenwich Mean Time
// REM         in the format YYYY-MM-DD HH:MM:SS-BBBBBBBBB in 24-hour
// REM         format like: 1995-02-27 18:01:03-500000000 which is equivalent
// REM         to 27-Feb-1995 6:01 PM at 3.5 seconds
// REM
CREATE TABLE row_status_type (
 rstat_type_cod      SMALLINT     NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (rstat_type_cod)
 );

// REM #13 -- Site Table
// REM
// REM   The site table holds information about the physical location
// REM   in the world where objects which are being monitored exist and
// REM   databases reside.
// REM
// REM   NOTE: For all for-profit businesses, the site_code is the 
// REM         D-U-N-S number of the location-- a randomly-generated
// REM         nine-digit number assigned by Dunn & Bradstreet.
// REM         The D-U-N-S number is based on a coding system called the
// REM         Data Universal Numbering System, hence it's name "D-U-N-S".
// REM         This code is used to identify 38 million current and former
// REM         business locations throught the world.  Each location of
// REM         a company is assigned a unique D-U-N-S number which does not
// REM         change and will not be reassigned if the location closes.
// REM         To locate your location's D-U-N-S number, please call Dun &
// REM         Bradstreet Information Resources Customer Service at 
// REM         1-800-333-0505.  This is a free service.
// REM
// REM   NOTE: The model stores the D-U-N-S number as an integer, which
// REM         does not preserve the leading zeroes in the DUNS number.  To
// REM         display the number to a user, left pad the number with zeroes
// REM         to 9 digits.
// REM
// REM   NOTE: For non-profit and government locations, you will need to
// REM         have a MIMOSA number assigned.  A group of numbers will
// REM         be assigned to your corporate organization.  A representative
// REM         from your corporate organization should e-mail Kenneth Bever
// REM         at kenneth_bever@hsb.com with the name of your organization,
// REM         the number of locations in our organization, your name,
// REM         title, and phone number.  You will be sent a range of
// REM         of MIMOSA numbers (all over 999,999,999) which you can
// REM         then assign to each of your locations.
// REM
// REM   NOTE: A negative D-U-N-S number can be used for temporary
// REM         assignment when no correct D-U-N-S number is available.
// REM         This should not be used permanently because the integration
// REM         of multiple site data will later be troublesome, i.e.,
// REM         both sites export with the D-U-N-S number of -1.
// REM
// REM   NOTE: The last_upd_db_site,last_upd_db_id columns are included
// REM         in all tables, except tables managed and populated by MIMOSA,
// REM         to store the database site and the DB identifier which made the
// REM         insert or last update to each row.  This is a foreign key to
// REM         to the site_database table, but we cannot define this
// REM         relationship because the table is not yet created.
// REM
// REM   NOTE: The optional field primary_sic relates to the primary Standard 
// REM         Industry Code (SIC) for the site.  This code is linked in a SIC
// REM         reference book to the type of industry the site is associated 
// REM         with.
// REM
// REM   NOTE: On address lines, line breaks are denoted by a backslash "\" 
// REM         character.
// REM
CREATE TABLE site (
 site_code           INTEGER      NOT NULL,
 company_name        VARCHAR(254) NOT NULL,
 site_name           VARCHAR(254) NOT NULL,
 phys_addr           VARCHAR(254),
 phys_city_name      VARCHAR(60),
 phys_state_abbr     CHAR(2),
 phys_postal_code    VARCHAR(10),
 phys_country_abb    CHAR(3),
 mail_addr           VARCHAR(254),
 mail_city_name      VARCHAR(60),
 mail_state_abbr     CHAR(2),
 mail_postal_code    VARCHAR(10),
 mail_country_abb    CHAR(3),
 us_ph_number        CHAR(10),
 int_ph_contry_no    VARCHAR(3),
 int_ph_city_no      VARCHAR(5),
 int_ph_local_no     VARCHAR(10),
 us_fax_number       CHAR(10),
 int_fax_cntry_no    VARCHAR(3),
 int_fax_city_no     VARCHAR(5),
 int_fax_local_no    VARCHAR(10),
 business_desc       VARCHAR(254),
 primary_sic         VARCHAR(8),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (site_code),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #15 -- Site Database Table
// REM
// REM   This table holds information about the machinery databases
// REM   located at the site.  It requires a unique db_id to exist
// REM   for each database.  This allows for databases to be merged.
// REM
// REM   NOTE: The vendor of the database is stored as a foreign key
// REM         in the mf_db_site, mf_db_id, mf_duns_code rows
// REM         which relates to the MANUFACTURER table defined below.
// REM         We cannot define it as a foreign key because the table
// REM         is not yet created, though indeed it is.
// REM
CREATE TABLE site_database (
 db_site             INTEGER      NOT NULL,
 db_id               INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 mf_db_site          INTEGER,
 mf_db_id            INTEGER,
 mf_duns_code        INTEGER,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (db_site, db_id),
    FOREIGN KEY (db_site) REFERENCES site (site_code),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #16 -- Manufacturer Table
// REM
// REM   NOTE: MIMOSA maintains tbe zero (0) mf_db_site entries in this 
// REM         table.  A database can add entries to this table, but must
// REM         insert the database's primary key in mf_db_site and mf_db_id
// REM         columns and then enter the Manfufacturer's corporate D-U-N-S
// REM         number in the mf_duns_code column.  If this is not known,
// REM         negative numbers can be generated.
// REM
// REM   NOTE: mf_duns_code is the D-U-N-S number of the corporate
// REM         office of the manufacturer of the object
// REM
// REM   NOTE: The optional field primary_sic relates to the primary Standard 
// REM         Industry Code (SIC) for the site.  This code is linked in a SIC
// REM         reference book to the type of industry the site is associated 
// REM         with.
// REM
// REM   NOTE: On address lines, line breaks are denoted by a backslash "\" 
// REM         character.
// REM
CREATE TABLE manufacturer (
 mf_db_site          INTEGER      NOT NULL,
 mf_db_id            INTEGER      NOT NULL,
 mf_duns_code        INTEGER      NOT NULL,
 manuf_trade_name    VARCHAR(254) NOT NULL,
 company_name        VARCHAR(254) NOT NULL,
 phys_addr           VARCHAR(254),
 phys_city_name      VARCHAR(30),
 phys_state_abbr     CHAR(2),
 phys_postal_code    VARCHAR(10),
 phys_country_abbr   CHAR(3),
 mail_addr           VARCHAR(254),
 mail_city_name      VARCHAR(60),
 mail_state_abbr     CHAR(2),
 mail_postal_code    VARCHAR(10),
 mail_country_abbr   CHAR(3),
 us_ph_number        CHAR(10),
 int_ph_country_no   VARCHAR(3),
 int_ph_city_no      VARCHAR(5),
 int_ph_local_no     VARCHAR(10),
 us_fax_number       CHAR(10),
 int_fax_country_no  VARCHAR(3),
 int_fax_city_no     VARCHAR(5),
 int_fax_local_no    VARCHAR(10),
 business_desc       VARCHAR(254),
 primary_sic         VARCHAR(8),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY ( mf_db_site, mf_db_id, mf_duns_code),
    FOREIGN KEY ( mf_db_site, mf_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #17 -- Service Segment Type Table
// REM
// REM This table standardizes the names of service segments:  production
// REM processes, their inputs and outputs, physical structures, systems,
// REM mechanical devices, and mechanical device areas.  Many of these
// REM segments appear on the engineering blueprints of the site.
// REM These are referred to as "service segments" in this model.  Service segment 
// REM types can be thought of as the labels which are used in plant layout 
// REM drawings showing the process flow, machine trains, and physical buildings 
// REM in a plant.
// REM
// REM   NOTE: MIMOSA Populates and maintains the sg_db_site Zero (0)
// REM         entries in this Table
// REM
// REM
CREATE TABLE segment_type (
 sg_db_site          INTEGER      NOT NULL,
 sg_db_id            INTEGER      NOT NULL,
 sg_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (sg_db_site, sg_db_id, sg_type_code),
    FOREIGN KEY (sg_db_site, sg_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #98 -- Segment Type Child Table
// REM
// REM This table shows the parent-child relationships structure of
// REM the logical taxonomy of segment types--from the general to more
// REM specific.  This table will support various classification schemes
// REM as desired by different MIMOSA databases.
// REM
CREATE TABLE segment_type_child (
 sg_db_site          INTEGER      NOT NULL,
 sg_db_id            INTEGER      NOT NULL,
 sg_type_code        INTEGER      NOT NULL,
 child_sg_db_site    INTEGER      NOT NULL,
 child_sg_db_id      INTEGER      NOT NULL,
 child_sg_type_code  INTEGER      NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (sg_db_site, sg_db_id, sg_type_code, child_sg_db_site,
        child_sg_db_id, child_sg_type_code),
    FOREIGN KEY (sg_db_site, sg_db_id, sg_type_code) REFERENCES 
        segment_type (sg_db_site, sg_db_id, sg_type_code),
    FOREIGN KEY segment_type_child (child_sg_db_site, child_sg_db_id,
        child_sg_type_code) REFERENCES segment_type (sg_db_site, sg_db_id,
        sg_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #18 -- Service Segment Table
// REM
// REM This table stores all the service segments which have been designed
// REM to perform a function at a site.  Service segments include production
// REM processes, their inputs and outputs, physical structures, systems,
// REM mechanical devices, and mechanical device areas.  Many of these
// REM segments appear on the engineering blueprints of the site.  
// REM These segments include components which perform a function 
// REM (Turbine-driven Pump 1A, Motor outboard bearing, etc.) but do NOT 
// REM describe the particular asset tracked by manufacturer,
// REM model number, & serial number in the database.  This is done in the
// REM asset table.  Some database track only data tied to service segments such
// REM as a machine train component, but do not tie the measurement data
// REM to the physical component assets installed at the time the data was 
// REM taken.  These databases cannot track, for example, a physical motor 
// REM which is taken out of one machine train, cleaned, and then later 
// REM used in another train.  Other systems track physical assets and 
// REM tie measurements to them.  In order to provide maximum flexibility, 
// REM this model allows both functional segment objects at a site and 
// REM physical objects at a site to be placed in the database and data
// REM can be related to both as necessary.  Table #44 (ASSET_ON_SEGMENT)
// REM stores the utilization of a particular asset on a given segment
// REM with the time it was installed and removed.
// REM
// REM The Segment_Child Table shows the parent-child relationships
// REM of segments to each other. For example, segment "Steam Turbine"
// REM at site "ABC" is the child of segment "Turbine Generator #1" 
// REM which is the child of segment "Power Generation Line #1". 
// REM The model allows for more than one segment to be the child of
// REM more than one segment.
// REM
// REM The segment_group_yn field when set to "Y" means that this segment
// REM is really a segment composed of 2 or more segments of the same type.
// REM If a count of total segments is made from the database, these group
// REM segments should be ignored.
// REM
// REM   NOTE: Segment_id is used like a barcode--to assign a unique,
// REM         non-changeable identifier since a primary key cannot change
// REM         and must uniquely define the entity.  The user_tag_ident
// REM         field is the identifier which is meaningful to the plant.
// REM
// REM         Computer systems monitoring or recording information on the 
// REM         same segment should utilize the same segment_site, segment_id
// REM         pair.
// REM
// REM         User_tag_ident is the user identification tag which
// REM         follows the nomenclature of the plant.  This is normally
// REM         an abbreviation or user-defined alpha-numeric code from which
// REM         the plant derives meaning.  This column is mandatory.
// REM
// REM         The "name" column is an optional column which is a full
// REM         description of the segment.
// REM
CREATE TABLE segment (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 sg_db_site          INTEGER      NOT NULL,
 sg_db_id            INTEGER      NOT NULL,
 sg_type_code        INTEGER      NOT NULL,
 segment_group_yn    CHAR(1)      NOT NULL,
 user_tag_ident      VARCHAR(254) NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (segment_site, segment_id),
    FOREIGN KEY (segment_site) REFERENCES site (site_code),
    FOREIGN KEY (sg_db_site, sg_db_id, sg_type_code) 
        REFERENCES segment_type (sg_db_site, sg_db_id, sg_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (segment_group_yn in ('Y','N'))
 );

// REM #19 -- Segment Child Table
// REM
// REM The Segment Child Table shows the parent-child relationships
// REM of segments to each other. For example, segment "Steam Turbine"
// REM at site "ABC" is the child of segment "Turbine Generator #1" 
// REM which is the child of segment "Power Generation Line #1". 
// REM The model allows for more than one segment to be the child of
// REM more than one segment.
// REM
// REM The mandatory ordering sequence specifies the order in which child
// REM segment will appear when an application requests "all children" of
// REM a particular segment.  The ordering sequence of machine segments, 
// REM coupling segments, and bearing segments on a rotating machine train 
// REM should conform to the MIMOSA guidelines as specified in 
// REM Document MIM-VB-001.
// REM
CREATE TABLE segment_child (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 child_sg_site       INTEGER      NOT NULL,
 child_sg_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (segment_site, segment_id, child_sg_site, child_sg_id),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment
        (segment_site, segment_id),
    FOREIGN KEY segment_child (child_sg_site, child_sg_id) REFERENCES segment
        (segment_site, segment_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #20 -- Segment Input Table
// REM
// REM The Segment Input Table describes the input segments which "feed" into
// REM another segment.  This is used to relate segments to
// REM production output processes.  The ordering sequence is for
// REM consistent output listings of the input process segments which 
// REM feed a segment.  No other use of the ordering sequence field is
// REM implied.
// REM
CREATE TABLE segment_input (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 input_sg_site       INTEGER      NOT NULL,
 input_sg_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (segment_site, segment_id, input_sg_site, input_sg_id),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment
        (segment_site, segment_id),
    FOREIGN KEY segment_input (input_sg_site, input_sg_id) REFERENCES segment
        (segment_site, segment_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #21 -- Segment Output Table
// REM
// REM The Segment Output Table describes the output segments which are
// REM produced or generated from a segment.  This is used to relate segments to
// REM production output processes.  The ordering sequence is for
// REM consistent output listings of the input process segments which 
// REM feed a segment.  No other use of the ordering sequence field is
// REM implied.
// REM
CREATE TABLE segment_output (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 output_sg_site      INTEGER      NOT NULL,
 output_sg_id        INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (segment_site, segment_id, output_sg_site, output_sg_id),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment
        (segment_site, segment_id),
    FOREIGN KEY segment_output (output_sg_site, output_sg_id) REFERENCES segment
        (segment_site, segment_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #22 -- Reference Unit Table
// REM
// REM   NOTE: MIMOSA populates and maintains this table.
// REM         No user-defined entries are supported.
// REM
CREATE TABLE ref_unit_type (
 ru_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 physics_descr       VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (ru_type_code),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #23 -- Engineering Unit Table
// REM
// REM   NOTE: MIMOSA Populates and maintains the eu_db_site Zero (0)
// REM         entries in this table.  To convert between units,
// REM         a multiplication factor from reference plus an offset
// REM         scalar is provided in the columns mult_fact_to_ref and
// REM         refer_off_to_ref, respectively.
// REM
// REM             Y[eng units] = (X[ref units] * mult_fact_to_ref) +
// REM                                  refer_off_to_ref
// REM
// REM             Y[ref units] = (X[eng units] - refer_off_to_ref) /
// REM                                  mult_fact_to_ref
// REM
CREATE TABLE eng_unit_type (
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 ru_type_code        INTEGER      NOT NULL,
 mult_fact_to_ref    DOUBLE       NOT NULL,
 refer_off_to_ref    DOUBLE       NOT NULL,
 name                VARCHAR(254) NOT NULL,
 abbrev              VARCHAR(254),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (ru_type_code) REFERENCES ref_unit_type (ru_type_code),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #24 -- Engineering Unit Enumerated List Table
// REM
// REM This table stores the alpha-numeric data names for engineering units
// REM which are of reference unit type "Enumerated List".
// REM
CREATE TABLE eng_unit_enum (
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          INTEGER      NOT NULL,
 data_name           VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (eu_db_site, eu_db_id, eu_type_code, data_value),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES 
        eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #25 -- Segment Numeric Data Type Table
// REM
// REM This table will define all the numeric data related to a segment
// REM
// REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
// REM
// REM
CREATE TABLE sg_num_dat_type (
 sn_db_site          INTEGER      NOT NULL,
 sn_db_id            INTEGER      NOT NULL,
 sn_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (sn_db_site, sn_db_id, sn_type_code),
    FOREIGN KEY (sn_db_site, sn_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #26 -- Segment Character Data Type Table
// REM
// REM This table will define all the alpha-numeric character data related to 
// REM a segment.
// REM
// REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
// REM
// REM
CREATE TABLE sg_chr_dat_type (
 sc_db_site          INTEGER      NOT NULL,
 sc_db_id            INTEGER      NOT NULL,
 sc_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (sc_db_site, sc_db_id, sc_type_code),
    FOREIGN KEY (sc_db_site, sc_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #27 -- Segment Numeric Data Table
// REM
// REM This table will hold all the numeric nameplate and composition
// REM data related to a segment.
// REM
// REM
// REM
CREATE TABLE segment_num_data (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 sn_db_site          INTEGER      NOT NULL,
 sn_db_id            INTEGER      NOT NULL,
 sn_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          DOUBLE       NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (segment_site, segment_id, sn_db_site, sn_db_id, sn_type_code),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment
        (segment_site, segment_id),
    FOREIGN KEY (sn_db_site, sn_db_id, sn_type_code) REFERENCES 
        sg_num_dat_type (sn_db_site, sn_db_id, sn_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES
        eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #28 -- Segment Character Data Table
// REM
// REM This table will hold all the alpha-numeric data related to a segment.
// REM
// REM
CREATE TABLE segment_chr_data (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 sc_db_site          INTEGER      NOT NULL,
 sc_db_id            INTEGER      NOT NULL,
 sc_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (segment_site, segment_id, sc_db_site, sc_db_id, sc_type_code),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment
        (segment_site, segment_id),
    FOREIGN KEY (sc_db_site, sc_db_id, sc_type_code) REFERENCES 
        sg_chr_dat_type (sc_db_site, sc_db_id, sc_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES
        eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #29 -- Segment/Asset Event Type Table
// REM
// REM This table holds the different types of possible events for segments and
// REM assets.  These include operating events and failure events.  An event
// REM is NOT work performed by an entity, but a log of the actual events which
// REM occurred at a service segment or asset over time.
// REM
// REM   NOTE: MIMOSA Populates and maintains the ev_db_site Zero (0)
// REM         entries in this Table
// REM
// REM
CREATE TABLE sg_as_event_type (
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (ev_db_site, ev_db_id, event_type_code),
    FOREIGN KEY (ev_db_site, ev_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #30 -- Segment Event Table
// REM
// REM This table holds the different events which occurred on segments.
// REM These include operating events and failure events.  An event
// REM is NOT work performed by an entity, but a log of the actual events which
// REM occurred at a service segment over time.
// REM
// REM     NOTE: gmt_event_start, gmt_event_stop, and gmt_stored are Greenwich 
// REM           Mean Time
// REM
// REM     NOTE: ev_loc_hr_delta is the the number of hours +/- GMT
// REM           to calculate the correct local time for the event.
// REM
// REM     NOTE: st_loc_hr_delta is the the number of hours +/- GMT
// REM           to calculate the correct local time for the date the
// REM           event row was stored in the database.
// REM
CREATE TABLE segment_event (
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 gmt_event_start     CHAR(29)     NOT NULL,
 gmt_event_stop      CHAR(29),
 ev_loc_hr_delta     SMALLINT,
 gmt_stored          CHAR(29),
 st_loc_hr_delta     SMALLINT,
 name                VARCHAR(254),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (segment_site, segment_id, ev_db_site, ev_db_id, 
        event_type_code, gmt_event_start),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment
        (segment_site, segment_id),
    FOREIGN KEY (ev_db_site, ev_db_id, event_type_code) REFERENCES 
        sg_as_event_type (ev_db_site, ev_db_id, event_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #31 -- Asset Type Table
// REM
// REM   NOTE: MIMOSA Populates and maintains the as_db_site Zero (0)
// REM         entries in this Table
// REM
CREATE TABLE asset_type (
 as_db_site          INTEGER      NOT NULL,
 as_db_id            INTEGER      NOT NULL,
 as_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (as_db_site, as_db_id, as_type_code),
    FOREIGN KEY (as_db_site, as_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #99 -- Asset Type Child Table
// REM
// REM This table shows the parent-child relationships structure of
// REM the logical taxonomy of asset types--from the general to more
// REM specific.  This table will support various classification schemes
// REM as desired by different MIMOSA databases.
// REM
CREATE TABLE asset_type_child (
 as_db_site          INTEGER      NOT NULL,
 as_db_id            INTEGER      NOT NULL,
 as_type_code        INTEGER      NOT NULL,
 child_as_db_site    INTEGER      NOT NULL,
 child_as_db_id      INTEGER      NOT NULL,
 child_as_type_code  INTEGER      NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (as_db_site, as_db_id, as_type_code, child_as_db_site,
        child_as_db_id, child_as_type_code),
    FOREIGN KEY (as_db_site, as_db_id, as_type_code) REFERENCES 
        asset_type (as_db_site, as_db_id, as_type_code),
    FOREIGN KEY asset_type_child (child_as_db_site, child_as_db_id,
        child_as_type_code) REFERENCES asset_type (as_db_site, as_db_id,
        as_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #32 -- Model/Part Number Table (Model Asset)
// REM
// REM This table will store the unique manufacturer and model/part number for
// REM a specific type of asset like a turbine, motor, bearing, etc.
// REM
// REM The revision number is part of the primary key and is used when
// REM a model of a piece of equipment is modified by the manufacturer
// REM and specifications will need to be tracked separately for each
// REM revision.  If no revision information is known, then this field
// REM should contain a zero.
// REM
// REM   NOTE: MIMOSA maintains tbe zero (0) md_db_site entries in this table
// REM         in order to provide standardized lists of known turbines,
// REM         bearings, etc.
// REM
// REM
CREATE TABLE model (
 mf_db_site          INTEGER      NOT NULL,
 mf_db_id            INTEGER      NOT NULL,
 mf_duns_code        INTEGER      NOT NULL,
 model_number        VARCHAR(254) NOT NULL,
 revision_number     INTEGER      NOT NULL,
 as_db_site          INTEGER      NOT NULL,
 as_db_id            INTEGER      NOT NULL,
 as_type_code        INTEGER      NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (mf_db_site, mf_db_id, mf_duns_code, model_number,
        revision_number),
    FOREIGN KEY (mf_db_site, mf_db_id, mf_duns_code) REFERENCES 
        manufacturer (mf_db_site, mf_db_id, mf_duns_code),
    FOREIGN KEY (as_db_site, as_db_id, as_type_code) REFERENCES 
        asset_type (as_db_site, as_db_id, as_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #97 -- Model/Part Child Table
// REM
// REM The Model/Part Child Table shows the parent-child relationships
// REM of model parts to each other.  This might be derived from the drawing 
// REM schematic diagrams provided by an equipment manufacturer.
// REM
// REM The mandatory ordering sequence specifies the order in which child
// REM asset will appear when an application requests "all children" of
// REM a particular model.
// REM
CREATE TABLE model_child (
 mf_db_site          INTEGER      NOT NULL,
 mf_db_id            INTEGER      NOT NULL,
 mf_duns_code        INTEGER      NOT NULL,
 model_number        VARCHAR(254) NOT NULL,
 revision_number     INTEGER      NOT NULL,
 child_mf_db_site    INTEGER      NOT NULL,
 child_mf_db_id      INTEGER      NOT NULL,
 child_mf_duns_code  INTEGER      NOT NULL,
 child_model_num     VARCHAR(254) NOT NULL,
 child_revision_num  INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (mf_db_site, mf_db_id, mf_duns_code, model_number,
        revision_number, child_mf_db_site, child_mf_db_id, child_mf_duns_code,
        child_model_num, child_revision_num),
    FOREIGN KEY (mf_db_site, mf_db_id, mf_duns_code, model_number,
        revision_number) REFERENCES model (mf_db_site, mf_db_id, mf_duns_code,
        model_number, revision_number),
    FOREIGN KEY model_child (child_mf_db_site, child_mf_db_id, 
        child_mf_duns_code, child_model_num, child_revision_num) REFERENCES 
        model (mf_db_site, mf_db_id, mf_duns_code, model_number, 
        revision_number),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #33 -- Asset Numeric Data Type Table
// REM
// REM This table will define all the numeric data related to a asset or a
// REM model of an asset.
// REM
// REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
// REM
// REM
CREATE TABLE as_num_dat_type (
 an_db_site          INTEGER      NOT NULL,
 an_db_id            INTEGER      NOT NULL,
 an_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (an_db_site, an_db_id, an_type_code),
    FOREIGN KEY (an_db_site, an_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #34 -- Asset Character Data Type Table
// REM
// REM This table will define all the alpha-numeric character data related to 
// REM an asset or a model of an asset.
// REM
// REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
// REM
// REM
CREATE TABLE as_chr_dat_type (
 ac_db_site          INTEGER      NOT NULL,
 ac_db_id            INTEGER      NOT NULL,
 ac_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (ac_db_site, ac_db_id, ac_type_code),
    FOREIGN KEY (ac_db_site, ac_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #35 -- Model Numeric Data Table
// REM
// REM This table will hold all the numeric nameplate and composition
// REM data related to a model.
// REM
// REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
// REM
// REM
// REM
CREATE TABLE model_num_data (
 mf_db_site          INTEGER      NOT NULL,
 mf_db_id            INTEGER      NOT NULL,
 mf_duns_code        INTEGER      NOT NULL,
 model_number        VARCHAR(254) NOT NULL,
 revision_number     INTEGER      NOT NULL,
 an_db_site          INTEGER      NOT NULL,
 an_db_id            INTEGER      NOT NULL,
 an_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          DOUBLE       NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (mf_db_site, mf_db_id, mf_duns_code, model_number, 
        revision_number, an_db_site, an_db_id, an_type_code),
    FOREIGN KEY (mf_db_site, mf_db_id, mf_duns_code, model_number,
        revision_number) REFERENCES model (mf_db_site, mf_db_id, mf_duns_code,
        model_number, revision_number),
    FOREIGN KEY (an_db_site, an_db_id, an_type_code) REFERENCES 
        as_num_dat_type (an_db_site, an_db_id, an_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES
        eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #36 -- Model Character Data Table
// REM
// REM This table will hold all the alpha-numeric nameplate and composition
// REM data related to a model.
// REM
// REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
// REM
// REM
CREATE TABLE model_chr_data (
 mf_db_site          INTEGER      NOT NULL,
 mf_db_id            INTEGER      NOT NULL,
 mf_duns_code        INTEGER      NOT NULL,
 model_number        VARCHAR(254) NOT NULL,
 revision_number     INTEGER      NOT NULL,
 ac_db_site          INTEGER      NOT NULL,
 ac_db_id            INTEGER      NOT NULL,
 ac_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (mf_db_site, mf_db_id, mf_duns_code, model_number, 
        revision_number, ac_db_site, ac_db_id, ac_type_code),
    FOREIGN KEY (mf_db_site, mf_db_id, mf_duns_code, model_number,
        revision_number) REFERENCES model (mf_db_site, mf_db_id, mf_duns_code,
        model_number, revision_number),
    FOREIGN KEY (ac_db_site, ac_db_id, ac_type_code) REFERENCES 
        as_chr_dat_type (ac_db_site, ac_db_id, ac_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES
        eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #37 -- Asset Table
// REM
// REM This table stores any asset at any site.  These
// REM might include actual motors, turbines, bearings, data collectors,
// REM transudcers, etc.  Optionally,one can associate this physical asset
// REM with a service segment of the same type as the asset in a 1 to 1 
// REM association.  For example, asset "Induction Motor Model XYZ" with
// REM a specific manufacturer can currently be installed
// REM on segment "Induction Motor" at site #343434323.
// REM
// REM The model allows for more than one asset to be the child of
// REM more than 1 parent asset through the Asset_Child table.
// REM
// REM   NOTE: Asset_org_site is the ORIGINAL site the object was
// REM         installed at and always remains part of the primary key.
// REM         This asset may move to another site, but the asset_org_site
// REM         and asset_id should remain the same.  This relates to the
// REM         Vehicle ID Number (VIN) on an automobile.  The car may
// REM         change owners by the VIN number does not change.
// REM
// REM         Asset_id is used like a barcode--to assign a unique,
// REM         non-changeable identifier since a primary key cannot change
// REM         and must uniquely define the entity.  The user_tag_ident
// REM         field is the identifier which is meaningful to the plant.
// REM
// REM         Computer systems monitoring or recording information on the 
// REM         same asset should utilize the same asset_org_site, asset_id
// REM         pair.
// REM
// REM         User_tag_ident is the user identification tag which
// REM         follows the nomenclature of the plant.  This is normally
// REM         an abbreviation or user-defined alpha-numeric code from which
// REM         the plant derives meaning.  This column is mandatory.
// REM
// REM         The "name" column is an optional column which is a full
// REM         description of the asset.
// REM
CREATE TABLE asset (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 as_db_site          INTEGER      NOT NULL,
 as_db_id            INTEGER      NOT NULL,
 as_type_code        INTEGER      NOT NULL,
 user_tag_ident      VARCHAR(254) NOT NULL,
 name                VARCHAR(254),
 mf_db_site          INTEGER,
 mf_db_id            INTEGER,
 mf_duns_code        INTEGER,
 model_number        VARCHAR(254),
 revision_number     INTEGER,
 serial_number       VARCHAR(254),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (asset_org_site, asset_id),
    FOREIGN KEY (asset_org_site) REFERENCES site (site_code),
    FOREIGN KEY (as_db_site, as_db_id, as_type_code) REFERENCES 
        asset_type (as_db_site, as_db_id, as_type_code),
    FOREIGN KEY (mf_db_site, mf_db_id, mf_duns_code, model_number, 
        revision_number) REFERENCES model (mf_db_site, mf_db_id, 
        mf_duns_code, model_number, revision_number),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #38 -- Asset Child Table
// REM
// REM The Asset Child Table shows the parent-child relationships
// REM of assets to each other. The model allows for more than one asset to 
// REM be the child of more than one asset.
// REM
// REM The mandatory ordering sequence specifies the order in which child
// REM asset will appear when an application requests "all children" of
// REM a particular asset.  The ordering sequence of machine assets, 
// REM coupling assets, and bearing assets on a rotating machine train 
// REM should conform to the MIMOSA guidelines as specified in 
// REM Document MIM-VB-001.
// REM
CREATE TABLE asset_child (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 child_as_site       INTEGER      NOT NULL,
 child_as_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (asset_org_site, asset_id, child_as_site, child_as_id),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset
        (asset_org_site, asset_id),
    FOREIGN KEY asset_child (child_as_site, child_as_id) REFERENCES asset
        (asset_org_site, asset_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #39 -- Asset Input Table
// REM
// REM The Asset Input Table describes the input assets which "feed" into
// REM another assets.  This is used to relate assetss to
// REM production output processes.  The ordering sequence is for
// REM consistent output listings of the input process assets which 
// REM feed a asset.  No other use of the ordering sequence field is
// REM implied.
// REM
CREATE TABLE asset_input (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 input_as_site       INTEGER      NOT NULL,
 input_as_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (asset_org_site, asset_id, input_as_site, input_as_id),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset
        (asset_org_site, asset_id),
    FOREIGN KEY asset_input (input_as_site, input_as_id) REFERENCES asset
        (asset_org_site, asset_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #40 -- Asset Output Table
// REM
// REM The Asset Output Table describes the output assets which are
// REM produced or generated from a asset.  This is used to relate assets to
// REM production output processes.  The ordering sequence is for
// REM consistent output listings of the input process assets which 
// REM feed a asset.  No other use of the ordering sequence field is
// REM implied.
// REM
CREATE TABLE asset_output (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 output_as_site      INTEGER      NOT NULL,
 output_as_id        INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (asset_org_site, asset_id, output_as_site, output_as_id),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset
        (asset_org_site, asset_id),
    FOREIGN KEY asset_output (output_as_site, output_as_id) REFERENCES asset
        (asset_org_site, asset_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #41 -- Asset Numeric Data Table
// REM
// REM This table will hold all the current numeric data related to an asset.
// REM
// REM
CREATE TABLE asset_num_data (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 an_db_site          INTEGER      NOT NULL,
 an_db_id            INTEGER      NOT NULL,
 an_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          DOUBLE       NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (asset_org_site, asset_id, an_db_site, an_db_id, an_type_code),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset
        (asset_org_site, asset_id),
    FOREIGN KEY (an_db_site, an_db_id, an_type_code) REFERENCES 
        as_num_dat_type (an_db_site, an_db_id, an_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES
        eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #42 -- Asset Character Data Table
// REM
// REM This table will hold all the current alpha-numeric character data 
// REM related to an asset.
// REM
// REM
CREATE TABLE asset_chr_data (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 ac_db_site          INTEGER      NOT NULL,
 ac_db_id            INTEGER      NOT NULL,
 ac_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (asset_org_site, asset_id, ac_db_site, ac_db_id, ac_type_code),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset
        (asset_org_site, asset_id),
    FOREIGN KEY (ac_db_site, ac_db_id, ac_type_code) REFERENCES 
        as_chr_dat_type (ac_db_site, ac_db_id, ac_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES
        eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #43 -- Asset Event Table
// REM
// REM This table holds the different types of possible events for assets.
// REM These include operating events and failure events.  An event
// REM is NOT work performed by an entity, but a log of the actual events which
// REM occurred at an asset over time.
// REM
// REM     NOTE: gmt_event_start, gmt_event_stop, and gmt_stored are Greenwich 
// REM           Mean Time
// REM
// REM     NOTE: ev_loc_hr_delta is the the number of hours +/- GMT
// REM           to calculate the correct local time for the event.
// REM
// REM     NOTE: st_loc_hr_delta is the the number of hours +/- GMT
// REM           to calculate the correct local time for the date the
// REM           event row was stored in the database.
// REM
CREATE TABLE asset_event (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 ev_db_site          INTEGER      NOT NULL,
 ev_db_id            INTEGER      NOT NULL,
 event_type_code     INTEGER      NOT NULL,
 gmt_event_start     CHAR(29)     NOT NULL,
 gmt_event_stop      CHAR(29),
 ev_loc_hr_delta     SMALLINT,
 gmt_stored          CHAR(29),
 st_loc_hr_delta     SMALLINT,
 name                VARCHAR(254),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (asset_org_site, asset_id, ev_db_site, ev_db_id, 
        event_type_code, gmt_event_start),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset
        (asset_org_site, asset_id),
    FOREIGN KEY (ev_db_site, ev_db_id, event_type_code) REFERENCES 
        sg_as_event_type (ev_db_site, ev_db_id, event_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #44 -- Asset Utilization on Segment History Table
// REM
// REM This table stores when a particular asset was utilized on a given
// REM segment and uses the date installed as part of the primary key.
// REM If not known when installed, a date of "0000-00-00 00:00:00-000000000"
// REM should be used.
// REM
CREATE TABLE asset_on_segment (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 segment_site        INTEGER      NOT NULL,
 segment_id          INTEGER      NOT NULL,
 gmt_installed       CHAR(29)     NOT NULL, 
 gmt_removed         CHAR(29),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (asset_org_site, asset_id, segment_site, segment_id, 
        gmt_installed),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset
        (asset_org_site, asset_id),
    FOREIGN KEY (segment_site, segment_id) REFERENCES segment
        (segment_site, segment_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #45 -- Asset Owner History Table
// REM
// REM This table stores the owner of a particular asset over time and
// REM stores the date purchased as part of the primary key.
// REM If not known when purchased, a date of "0000-00-00 00:00:00-000000000"
// REM should be used.  If these assets are not currently active in the
// REM asset_on_segment table, then they could be considered "spares".
// REM
CREATE TABLE asset_owner (
 asset_org_site      INTEGER      NOT NULL,
 asset_id            INTEGER      NOT NULL,
 gmt_purchased       CHAR(29)     NOT NULL,
 sold_to_site        INTEGER      NOT NULL,
 purch_from_site     INTEGER,
 gmt_sold            CHAR(29),
 gmt_discarded       CHAR(29),
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (asset_org_site, asset_id, gmt_purchased),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES asset
        (asset_org_site, asset_id),
    FOREIGN KEY site_purch (purch_from_site) REFERENCES site (site_code),
    FOREIGN KEY site_sold (sold_to_site) REFERENCES site (site_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #55 -- Measurement Location Type Table
// REM
// REM This table stores all the various types of measurement locations.
// REM
// REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
// REM
// REM
CREATE TABLE meas_loc_type (
 ml_db_site          INTEGER      NOT NULL,
 ml_db_id            INTEGER      NOT NULL,
 ml_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (ml_db_site, ml_db_id, ml_type_code),
    FOREIGN KEY (ml_db_site, ml_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #51 -- Data Source Type Table
// REM
// REM This table stores all the various types of data sources.
// REM
// REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
// REM
// REM
CREATE TABLE data_source_type (
 ds_db_site          INTEGER      NOT NULL,
 ds_db_id            INTEGER      NOT NULL,
 ds_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (ds_db_site, ds_db_id, ds_type_code),
    FOREIGN KEY (ds_db_site, ds_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #53 -- Transducer Type Table
// REM
// REM A subset of the asset type table which defines the types of assets
// REM which are valid types of transducers.
// REM
// REM The tr_type_abbrev is an optional 2-character abbrev for the tranducer 
// REM type as defined for vibration in MIMOSA Document MIM-VB-001.
// REM
// REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
// REM
CREATE TABLE trans_type (
 tr_db_site          INTEGER      NOT NULL,
 tr_db_id            INTEGER      NOT NULL,
 tr_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 tr_type_abbrev      CHAR(2),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (tr_db_site, tr_db_id, tr_type_code),
    FOREIGN KEY (tr_db_site, tr_db_id, tr_type_code) REFERENCES
        asset_type (as_db_site, as_db_id, as_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #46 -- Transducer Sensitive Axis Direction Type Table
// REM
// REM This table stores types of sensitive axis directions which 
// REM relate to tranducers placed at measurement locations on machinery.  
// REM The axis direction to use for monitoring rotating machinery should 
// REM conform to the MIMOSA guidelines as specified in Document MIM-VB-001.
// REM
// REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
// REM
CREATE TABLE tr_axis_dir_type (
 ta_db_site          INTEGER      NOT NULL,
 ta_db_id            INTEGER      NOT NULL,
 ta_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (ta_db_site, ta_db_id, ta_type_code),
    FOREIGN KEY (ta_db_site, ta_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #47 -- Measurement Location Table
// REM
// REM This table is used to identify the location where actual measurements 
// REM will be taken, along with the type of measurement location, the source 
// REM of the measurement data, the type of transducer which will be used
// REM (if applicable), the degree of the tranducer's angular orientation 
// REM (if applicable), the corresponding transducer sensitive axis direction 
// REM code (if applicable), and to which segment or asset the location is 
// REM associated.  
// REM
// REM The meas_loc_id should be assigned by a plant to be the same across 
// REM all database systems.  This allows data from one collection system 
// REM to be merged with another collection system for the same location.
// REM
// REM Although this table does not physically restrict it, a measurement 
// REM location must be assigned to either a segment or an asset in this 
// REM table, as indicated by the segment_or_asset column, but not both.
// REM
// REM The degree of the tranducer's angular orientation (column ta_orient_deg)
// REM (0-360) and the corresponding tranducer sensitive axis direction code, 
// REM if applicable, is stored in this table.
// REM
// REM The specification of the MIMOSA Vibration Measurement Location Code,
// REM as specified in Document MIM-VB-001, is based on appending the following
// REM columns together to form a 14-character unique MIMOSA Location code.
// REM The following columns from this table are used directly or as foreign key
// REM references to create this code:
// REM
// REM   Component Part => mim_user_prefix (4 characters of XXXX if null)
// REM   Bearing Housing Location on Machine System =>
// REM         mim_loc_seq (3 digits with leading zeroes)
// REM   Transducer Type Code => TRANS_TYPE.tr_type_abbrev (2 characters
// REM         referenced by tr_db_site, tr_db_id, tr_type_code or XX if null)
// REM   Angular Orientation => ta_oreint_deg (3 digits with leading zeroes
// REM         or XXX if null)
// REM   Transducer Sensitive Axis Direction => 1st character from
// REM         TR_AXIS_DIR_TYPE.name referenced by ta_db_site, ta_db_id,
// REM         ta_type_code
// REM   Direction of Motion => motion_direction (1 character of X if null)
// REM
// REM   NOTE: meas_loc_id is used like a barcode--to assign a unique,
// REM         non-changeable identifier since a primary key key cannot change
// REM         and must uniquely define the entity.  The user_tag_ident field
// REM         is the identifier which is meaningful to the plant.
// REM
// REM         Computer systems monitoring or recording information on the 
// REM         same location should utilize the same meas_loc_site, meas_loc_id
// REM         pair.
// REM         
// REM         User_tag_ident is the user identification tag which
// REM         follows the nomenclature of the plant.  This is normally
// REM         an abbreviation or user-defined alpha-numeric code from which
// REM         the plant derives meaning.  This column is mandatory.
// REM
// REM
CREATE TABLE meas_location (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 ml_db_site          INTEGER      NOT NULL,
 ml_db_id            INTEGER      NOT NULL,
 ml_type_code        INTEGER      NOT NULL,
 segment_or_asset    CHAR(1)      NOT NULL,
 segment_site        INTEGER,
 segment_id          INTEGER,
 asset_org_site      INTEGER,
 asset_id            INTEGER,
 ds_db_site          INTEGER,
 ds_db_id            INTEGER,
 ds_type_code        INTEGER,
 tr_db_site          INTEGER,
 tr_db_id            INTEGER,
 tr_type_code        INTEGER,
 ta_orient_deg       INTEGER,
 ta_db_site          INTEGER,
 ta_db_id            INTEGER,
 ta_type_code        INTEGER,
 mim_loc_seq         INTEGER,
 motion_direction    CHAR(1),
 mim_user_prefix     CHAR(4),
 user_tag_ident      VARCHAR(254) NOT NULL,
 barcode             VARCHAR(254),
 name                VARCHAR(254),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (meas_loc_site, meas_loc_id),
    FOREIGN KEY (meas_loc_site) REFERENCES site (site_code),
    FOREIGN KEY (ml_db_site, ml_db_id, ml_type_code) REFERENCES
        meas_loc_type (ml_db_site, ml_db_id, ml_type_code),
    FOREIGN KEY (segment_site, segment_id) REFERENCES
        segment (segment_site, segment_id),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES
        asset (asset_org_site, asset_id),
    FOREIGN KEY (ds_db_site, ds_db_id, ds_type_code) REFERENCES 
        data_source_type (ds_db_site, ds_db_id, ds_type_code),
    FOREIGN KEY (tr_db_site, tr_db_id, tr_type_code) REFERENCES 
        trans_type (tr_db_site, tr_db_id, tr_type_code),
    FOREIGN KEY (ta_db_site, ta_db_id, ta_type_code) REFERENCES 
        tr_axis_dir_type (ta_db_site, ta_db_id, ta_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (segment_or_asset in ('S','A')),
    CHECK (motion_direction in ('N','R'))
 );

// REM #48 -- Ordered List Table
// REM
// REM This table is used to identify the name an ordered list for a database.
// REM
// REM   NOTE: ord_list_id should be a non-changeable, unique
// REM         identifier since a primary key cannot change and
// REM         must uniquely define the entity.  System-assigned
// REM         "hidden" ord_list_id's are strongly recommended.
// REM
CREATE TABLE ordered_list (
 ord_list_db_site    INTEGER      NOT NULL,
 ord_list_db_id      INTEGER      NOT NULL,
 ord_list_id         INTEGER      NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (ord_list_db_site, ord_list_db_id, ord_list_id),
    FOREIGN KEY (ord_list_db_site, ord_list_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #49 -- Ordered List of Measurement Locations Table
// REM
// REM This table is used to store the measurement locations for a
// REM a given ordered list.
// REM
// REM
CREATE TABLE meas_loc_list (
 ord_list_db_site    INTEGER      NOT NULL,
 ord_list_db_id      INTEGER      NOT NULL,
 ord_list_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq),
    FOREIGN KEY (ord_list_db_site, ord_list_db_id, ord_list_id) REFERENCES
        ordered_list (ord_list_db_site, ord_list_db_id, ord_list_id),
    FOREIGN KEY (meas_loc_site, meas_loc_id) REFERENCES 
        meas_location (meas_loc_site, meas_loc_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #50 -- Ordered List of Eng. Units at Measurement Locations Table
// REM
// REM This table is used to store the measurement location with associated
// REM engineering units and channel number (set to 1 if not a multi-channel 
// REM input) which has been requested for data collection / reporting at a 
// REM certain place (ordering_seq) on an ordered list.
// REM
// REM
CREATE TABLE mloc_unit_list (
 ord_list_db_site    INTEGER      NOT NULL,
 ord_list_db_id      INTEGER      NOT NULL,
 ord_list_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 channel_number      INTEGER      NOT NULL,
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq, 
        channel_number),
    FOREIGN KEY (ord_list_db_site, ord_list_db_id, ord_list_id) REFERENCES
        ordered_list (ord_list_db_site, ord_list_db_id, ord_list_id),
    FOREIGN KEY (meas_loc_site, meas_loc_id) REFERENCES 
        meas_location (meas_loc_site, meas_loc_id),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES 
        eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #52 -- Data Source Asset Table  (Subset of Asset Table)
// REM
// REM This table is a subset of the asset table and catalogs all 
// REM the data asset sources (collectors, monitoring systems, etc.) 
// REM used to take measurements.
// REM
// REM Measurements can be stored in the measurement event table, however,
// REM without data source information, so entries in this 
// REM table are not required.
// REM
// REM
CREATE TABLE data_source (
 ds_asset_site       INTEGER      NOT NULL,
 ds_asset_id         INTEGER      NOT NULL,
 ds_db_site          INTEGER      NOT NULL,
 ds_db_id            INTEGER      NOT NULL,
 ds_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254),
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (ds_asset_site, ds_asset_id),
    FOREIGN KEY (ds_asset_site, ds_asset_id) REFERENCES asset
        (asset_org_site, asset_id),
    FOREIGN KEY (ds_db_site, ds_db_id, ds_type_code) REFERENCES
        data_source_type (ds_db_site, ds_db_id, ds_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #54 -- Transducer Asset Table  (Subset of Asset Table)
// REM
// REM This table is a subset of the asset table and catalogs all the 
// REM transducers used to take measurements.  The output amplitude and
// REM output amplitude units are the raw analog output signal which comes from
// REM the transducer (i.e. 200 millivolts) representing 1 resulting
// REM engineering unit (the "per" engineering unit fields, i.e. MIL). 
// REM
// REM Measurements can be stored in the measurement event table, however,
// REM without transducer information, so entries in this table are not
// REM required.
// REM
CREATE TABLE transducer (
 tr_asset_site       INTEGER      NOT NULL,
 tr_asset_id         INTEGER      NOT NULL,
 tr_db_site          INTEGER      NOT NULL,
 tr_db_id            INTEGER      NOT NULL,
 tr_type_code        INTEGER      NOT NULL,
 out_eu_db_site      INTEGER,
 out_eu_db_id        INTEGER,
 out_eu_type_code    INTEGER,
 out_amplitude       DOUBLE,
 per_eu_db_site      INTEGER,
 per_eu_db_id        INTEGER,
 per_eu_type_code    INTEGER,
 gmt_last_calib      CHAR(29),
 self_powered_yn     CHAR(1),
 name                VARCHAR(254),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (tr_asset_site, tr_asset_id),
    FOREIGN KEY (tr_asset_site, tr_asset_id) REFERENCES asset
        (asset_org_site, asset_id),
    FOREIGN KEY (tr_db_site, tr_db_id, tr_type_code) REFERENCES 
        trans_type (tr_db_site, tr_db_id, tr_type_code),
    FOREIGN KEY out_eng_unit (out_eu_db_site, out_eu_db_id, out_eu_type_code) 
        REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY per_eng_unit (per_eu_db_site, per_eu_db_id, per_eu_type_code) 
        REFERENCES eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (self_powered_yn in (NULL,'Y','N'))
 );

// REM
// REM #88 -- Data Quality Type Table
// REM
// REM   The data quality type defines the various quality states which
// REM   data in tables can be classified.  These come from the ISO 9000-2
// REM   status guidelines:
// REM
// REM                        1 = Not Inspected, Quality Unknown
// REM                        2 = Inspected and Accepted, Quality Good
// REM                        3 = Inspected and On Hold, Quality Under Review
// REM                        4 = Inspected and Rejected, Quality Bad
// REM
// REM   NOTE: MIMOSA populates and maintains this table.
// REM         No user-defined entries are supported.
// REM
CREATE TABLE data_qual_type (
 dqual_type_code     SMALLINT     NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (dqual_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #56 -- Measurement Event History Table
// REM
// REM This table is a history of data collection events occurring at
// REM measurement locations.  This event could have recorded a single 
// REM numeric value of a certain type, or a group of related signal 
// REM processed measurements.  Each measurement event relates back to one
// REM measurement location.  
// REM
// REM Foreign keys are defined to the segment, asset, 
// REM data collection source, and transducer tables in order for a system to 
// REM track which segment and/or which asset and which data collection 
// REM source and transducer the measurement is tied to at at this 
// REM particular instance in time.  This table does not contain the actual
// REM data, but the fact that on a given time, at a measurement location
// REM which was then associated with a physical object and/or a functional
// REM object, a measurement of a certain location type was taken.
// REM
// REM     NOTE: The non-mandatory segment_site,segment_id columns are for 
// REM           measurement locations on assets where the actual segment 
// REM           where the asset is installed needs to be captured with 
// REM           the measurement event.
// REM
// REM     NOTE: The non-mandatory asset_org_site,asset_id columns are for 
// REM           measurement locations on segments where the actual asset
// REM           installed on the segment needs to be captured with 
// REM           the measurement event.
// REM
// REM     NOTE: ev_loc_hr_delta is the the number of hours +/- GMT
// REM           to calculate the correct local time for the event.
// REM
// REM     NOTE: st_loc_hr_delta is the the number of hours +/- GMT
// REM           to calculate the correct local time for the date the
// REM           event row was stored in the database.
// REM
CREATE TABLE meas_event (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           CHAR(29)     NOT NULL,
 ev_loc_hr_delta     SMALLINT,
 gmt_stored          CHAR(29),
 st_loc_hr_delta     SMALLINT,
 segment_site        INTEGER,
 segment_id          INTEGER,
 asset_org_site      INTEGER,
 asset_id            INTEGER,
 ds_asset_site       INTEGER,
 ds_asset_id         INTEGER,
 tr_asset_site       INTEGER,
 tr_asset_id         INTEGER,
 dqual_type_code     SMALLINT     NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (meas_loc_site, meas_loc_id) REFERENCES
        meas_location (meas_loc_site, meas_loc_id),
    FOREIGN KEY (segment_site, segment_id) REFERENCES
        segment (segment_site, segment_id),
    FOREIGN KEY (asset_org_site, asset_id) REFERENCES
        asset (asset_org_site, asset_id),
    FOREIGN KEY (ds_asset_site, ds_asset_id) REFERENCES
        data_source (ds_asset_site, ds_asset_id),
    FOREIGN KEY (tr_asset_site, tr_asset_id) REFERENCES
        transducer (tr_asset_site, tr_asset_id),
    FOREIGN KEY (dqual_type_code) REFERENCES
        data_qual_type (dqual_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #100 -- Measurement Event Associations
// REM
// REM This table contains measurement events which are related to one
// REM another.  This is used in vibration to associate a vibration
// REM measurement event to its corresponding tachometer signal measurement
// REM event and for multi-channel data which are related to each other.
// REM
CREATE TABLE meas_event_assoc (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           CHAR(29)     NOT NULL,
 related_mloc_site   INTEGER      NOT NULL,
 related_mloc_id     INTEGER      NOT NULL,
 related_gmt_event   CHAR(29)     NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, related_mloc_site,
        related_mloc_id, related_gmt_event),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES 
        meas_event (meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY related_meas_event (related_mloc_site, related_mloc_id,
        related_gmt_event) REFERENCES meas_event (meas_loc_site, meas_loc_id,
        gmt_event),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #57 -- Measurement Event Remarks Table 
// REM
// REM This table is where each measurement event textual remarks are 
// REM recorded.  This table is for an operator or analyst to put in
// REM free-form notes about why this measurement event was recorded, etc.
// REM
// REM This table should NOT store measurement event alpha-numeric
// REM character data like dates or user identifiers which should be tracked
// REM over time.  These should be stored in the measurement event character 
// REM value table #59 (MEVENT_CHR_VALUE) with a specific engineering unit 
// REM associated with it.
// REM
CREATE TABLE meas_event_rem (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           CHAR(29)     NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 remark_text         VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, ordering_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES 
        meas_event (meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #58 -- Measurement Event Numeric Data Table 
// REM
// REM This table is where all simple numeric data values which are related to
// REM to a measurement event for non-signal processed data is stored.
// REM
// REM This table could store simple pressures, temperatures, tachometer voltages,
// REM load readings, etc. which do not need additional information to interpret.
// REM
// REM Do NOT store frequency-related overall vibration amplitude data in this table, 
// REM which should be stored in the signal-processed, single amplitude value/vector
// REM table (SP_AMPL_DATA).
// REM
// REM Do NOT store fluid/gas test data nor electrical test data which require a 
// REM "test type" in order to comprehend.  Version 1.1 of CRIS will provide specific
// REM tables for this type of data.
// REM
CREATE TABLE mevent_num_data (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           CHAR(29)     NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          DOUBLE       NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, eu_db_site, 
        eu_db_id, eu_type_code),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES 
        meas_event (meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES
        eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #59 -- Measurement Event Character Data Table 
// REM
// REM This table is where all alpha-numeric data values which are related to
// REM to a measurement event for non-signal processed data is stored.
// REM
// REM This table stores measurement location data which needs to
// REM be tracked over time and contains an alpha-numeric code or date.
// REM
CREATE TABLE mevent_chr_data (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           CHAR(29)     NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, eu_db_site, 
        eu_db_id, eu_type_code),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES 
        meas_event (meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES 
        eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #60 -- Alarm Severity Table
// REM
// REM This table stores the entries possible for alarm severity.
// REM
// REM   NOTE: MIMOSA populates and maintains this table.
// REM         No user-defined entries are supported.
// REM
CREATE TABLE alarm_severity (
 al_severity_rank    SMALLINT     NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (al_severity_rank),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #61 -- Alarm Type Table
// REM
// REM This table stores the different types of alarms used by a database,
// REM along with its severity ranking and name.
// REM
// REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
// REM
CREATE TABLE alarm_type (
 al_db_site          INTEGER      NOT NULL,
 al_db_id            INTEGER      NOT NULL,
 al_type_code        INTEGER      NOT NULL,
 al_severity_rank    SMALLINT     NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (al_db_site, al_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (al_severity_rank) REFERENCES alarm_severity (al_severity_rank),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #62 -- Measurement Location Numeric Data Alarm Region Table
// REM
// REM This table will store all simple numeric low-high alarm regions 
// REM for numeric, non-signal processed data at a specified measurement
// REM location for a site database.
// REM
// REM This table allows every site database to store their own set of
// REM alarm regions for each measurement location/event type/eng. unit
// REM combination.  In addition, the table stores the history of the 
// REM changes of these alarm regions.  An application may only want the
// REM maximum gmt_alarm_start of a particular region and ignore the history 
// REM of how the alarm changed over time.
// REM
// REM  The interpretation of the 2 data columns:
// REM
// REM       If <current_amplitude> >= min_amplitude AND
// REM          <current_amplitude> <  max_amplitude
// REM       Then alarm region is triggered.
// REM
// REM   NOTE: To create a region which ends at +infinity set the 
// REM         max_amplitude = MAXDOUBLE value.  To create a region
// REM         which starts at -infinity set the min_amplitude to 
// REM         MINDOUBLE value.
// REM
// REM   NOTE: If a system does not track the history of alarm levels, 
// REM         then the gmt_alarm_start field can be set to the earliest
// REM         possible date the alarm could have been created in the database.
// REM
// REM   NOTE: st_loc_hr_delta is the the number of hours +/- GMT
// REM         to calculate the correct local time for the date the
// REM         alarm started.
// REM
// REM   NOTE: If a system does not track the history of alarm levels,
// REM         then the gmt_alarm_start field can be set to the earliest
// REM         possible date the alarm could have been created in the database.
// REM
CREATE TABLE mloc_num_alrm_rg (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 al_db_site          INTEGER      NOT NULL,
 al_db_id            INTEGER      NOT NULL,
 al_type_code        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 gmt_alarm_start     CHAR(29)     NOT NULL,
 st_loc_hr_delta     SMALLINT,
 min_amplitude       DOUBLE       NOT NULL,
 max_amplitude       DOUBLE       NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (meas_loc_site, meas_loc_id, al_db_site, al_db_id, al_type_code,
        eu_db_site, eu_db_id, eu_type_code, gmt_alarm_start),
    FOREIGN KEY (meas_loc_site, meas_loc_id) REFERENCES
        meas_location (meas_loc_site, meas_loc_id),
    FOREIGN KEY (al_db_site, al_db_id, al_type_code) REFERENCES 
        alarm_type (al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES 
        eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #63 -- Measurement Event Numeric Data Alarm Table 
// REM
// REM This table stores all the alarms triggered by the numeric value
// REM stored in the MEVENT_NUM_DATA table.  If data is available in the
// REM Measurement Location Numeric Data Alarm Region Table, then the alarm
// REM data in this table can be derived and does not need to be stored here.
// REM However, some systems do not send all the alarm region data, and we 
// REM need to store the fact that an alarm was triggered.
// REM
CREATE TABLE mevent_num_alarm (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           CHAR(29)     NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 al_db_site          INTEGER      NOT NULL,
 al_db_id            INTEGER      NOT NULL,
 al_type_code        INTEGER      NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, eu_db_site, 
        eu_db_id, eu_type_code, al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event, eu_db_site, 
        eu_db_id, eu_type_code) REFERENCES mevent_num_data (meas_loc_site, 
        meas_loc_id, gmt_event, eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES 
        eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (al_db_site, al_db_id, al_type_code) REFERENCES alarm_type
        (al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #64 -- Signal Process Type Table
// REM
// REM This table stores all the various types of signal processing that
// REM could be defined.
// REM
// REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
// REM
// REM
CREATE TABLE signal_proc_type (
 sp_db_site          INTEGER      NOT NULL,
 sp_db_id            INTEGER      NOT NULL,
 sp_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (sp_db_site, sp_db_id, sp_type_code),
    FOREIGN KEY (sp_db_site, sp_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #65 -- Signal Process Block Table
// REM
// REM This table will store all the signal process block entries specified  
// REM in a given database, each of a specified signal processing type and  
// REM assigns each a unique signal_proc_id to each entry in each database.
// REM
CREATE TABLE signal_proc_blk (
 sp_blk_db_site      INTEGER      NOT NULL,
 sp_blk_db_id        INTEGER      NOT NULL,
 sp_block_id         INTEGER      NOT NULL,
 sp_db_site          INTEGER      NOT NULL,
 sp_db_id            INTEGER      NOT NULL,
 sp_type_code        INTEGER      NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (sp_blk_db_site, sp_blk_db_id, sp_block_id),
    FOREIGN KEY (sp_blk_db_site, sp_blk_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (sp_db_site, sp_db_id, sp_type_code) REFERENCES
        signal_proc_type (sp_db_site, sp_db_id, sp_type_code),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #66 -- Signal Process Block Numeric Data Type Table
// REM
// REM This table stores all the various types of numeric data associated
// REM with signal process blocks.  Data associated with averaging, 
// REM source detection, and windows can optionally be stored here, but should
// REM be specified when data is stored in the actual time  waveform, FFT, CPB,
// REM or single amplitude value/vector data tables.
// REM
// REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
// REM
CREATE TABLE sp_num_dat_type (
 spn_db_site         INTEGER      NOT NULL,
 spn_db_id           INTEGER      NOT NULL,
 spn_type_code       INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (spn_db_site, spn_db_id, spn_type_code),
    FOREIGN KEY (spn_db_site, spn_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #67 -- Signal Process Block Numeric Data Table
// REM
// REM This table will store the numeric data related to an entry in the 
// REM the signal process block table. 
// REM
// REM   NOTE:  Care must be taken not to change the numeric data of blocks used
// REM          in a signal process stream if measurements have been stored 
// REM          for the stream.
// REM
CREATE TABLE sp_blk_num_data (
 sp_blk_db_site      INTEGER      NOT NULL,
 sp_blk_db_id        INTEGER      NOT NULL,
 sp_block_id         INTEGER      NOT NULL,
 spn_db_site         INTEGER      NOT NULL,
 spn_db_id           INTEGER      NOT NULL,
 spn_type_code       INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 data_value          DOUBLE       NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (sp_blk_db_site, sp_blk_db_id, sp_block_id, spn_db_site,
        spn_db_id, spn_type_code),
    FOREIGN KEY (sp_blk_db_site, sp_blk_db_id, sp_block_id) REFERENCES
        signal_proc_blk (sp_blk_db_site, sp_blk_db_id, sp_block_id),
    FOREIGN KEY (spn_db_site, spn_db_id, spn_type_code) REFERENCES
        sp_num_dat_type (spn_db_site, spn_db_id, spn_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES 
        eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #68 -- Signal Process Stream Table
// REM
// REM This table will store the signal process streams for a given database.
// REM These streams will contain sequences of signal process blocks which
// REM define the processing sequence which data passed through.
// REM
// REM Actual single amplitude value/vector data, FFT data, time waveform data,
// REM and CPB data can optionally be associated with an entry in this table.
// REM
CREATE TABLE sp_stream (
 sp_str_db_site      INTEGER      NOT NULL,
 sp_str_db_id        INTEGER      NOT NULL,
 sp_stream_id        INTEGER      NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (sp_str_db_site, sp_str_db_id, sp_stream_id),
    FOREIGN KEY (sp_str_db_site, sp_str_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #69 -- Signal Process Stream Blocks Table
// REM
// REM This table details the sequence of signal process blocks for each
// REM signal process stream.
// REM
// REM   NOTE:  Care must be taken not to change the sequence of blocks in
// REM          a stream if measurements have been stored for the stream.
// REM          Normally, a new stream should be defined instead of 
// REM          updating the original stream.
// REM          
// REM
CREATE TABLE sp_stream_block (
 sp_str_db_site      INTEGER      NOT NULL,
 sp_str_db_id        INTEGER      NOT NULL,
 sp_stream_id        INTEGER      NOT NULL,
 sp_blk_db_site      INTEGER      NOT NULL,
 sp_blk_db_id        INTEGER      NOT NULL,
 sp_block_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (sp_str_db_site, sp_str_db_id, sp_stream_id, sp_blk_db_site,
        sp_blk_db_id, sp_block_id),
    FOREIGN KEY (sp_str_db_site, sp_str_db_id, sp_stream_id) REFERENCES
        sp_stream (sp_str_db_site, sp_str_db_id, sp_stream_id),
    FOREIGN KEY (sp_blk_db_site, sp_blk_db_id, sp_block_id) REFERENCES
        signal_proc_blk (sp_blk_db_site, sp_blk_db_id, sp_block_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #70 -- Average Type Table
// REM
// REM This table stores different types of signal processing averaging methods.
// REM
// REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
// REM
CREATE TABLE average_type (
 ave_db_site         INTEGER      NOT NULL,
 ave_db_id           INTEGER      NOT NULL,
 ave_type_code       INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (ave_db_site, ave_db_id, ave_type_code),
    FOREIGN KEY (ave_db_site, ave_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #71 -- Average Weight Type Table
// REM
// REM This table stores different types of signal processing average
// REM weighting methods.
// REM
// REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
// REM
CREATE TABLE ave_weight_type (
 ave_wt_db_site      INTEGER      NOT NULL,
 ave_wt_db_id        INTEGER      NOT NULL,
 ave_wt_type_code    INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code),
    FOREIGN KEY (ave_wt_db_site, ave_wt_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #72 -- Average Synchronization Type Table
// REM
// REM This table stores different types of signal processing averaging 
// REM synchronization methods.
// REM
// REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
// REM
CREATE TABLE ave_synch_type (
 ave_sy_db_site      INTEGER      NOT NULL,
 ave_sy_db_id        INTEGER      NOT NULL,
 ave_sy_type_code    INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code),
    FOREIGN KEY (ave_sy_db_site, ave_sy_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #73 -- Source Signal Detector Type Table
// REM
// REM This table stores different source signal detector types.
// REM
// REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
// REM
CREATE TABLE src_detect_type (
 src_dt_db_site      INTEGER      NOT NULL,
 src_dt_db_id        INTEGER      NOT NULL,
 src_dt_type_code    INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (src_dt_db_site, src_dt_db_id, src_dt_type_code),
    FOREIGN KEY (src_dt_db_site, src_dt_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #74 -- Post-Processed Signal Processing Scaling Mode Table
// REM
// REM This table stores different types of signal processing scaling methods.
// REM
// REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
// REM
CREATE TABLE post_scaling_type (
 pst_sc_db_site      INTEGER      NOT NULL,
 pst_sc_db_id        INTEGER      NOT NULL,
 pst_sc_type_code    INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code),
    FOREIGN KEY (pst_sc_db_site, pst_sc_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #75 -- Signal-Processed Frequency/Order Single Amplitude/Vector Data
// REM        Table
// REM
// REM This table will store 1 or more single amplitudes AND/OR single vectors
// REM which are related to frequency or order ranges which resulted as an 
// REM output of a measurement event.
// REM
// REM A vector can be stored by placing the angle in degrees in the
// REM column angle_in_degrees.
// REM
// REM  NOTE: If the source signal detector type is "FFT Power RMS", then the 
// REM        amplitude field is calculated from the spectra by taking the 
// REM        square root of the sum of all amplitude values squared which is 
// REM        then divided by the window factor.
// REM
// REM
CREATE TABLE sp_ampl_data (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           CHAR(29)     NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 pst_sc_db_site      INTEGER      NOT NULL,
 pst_sc_db_id        INTEGER      NOT NULL,
 pst_sc_type_code    INTEGER      NOT NULL,
 freq_or_order       CHAR(1)      NOT NULL,
 min_in_hz_or_ord    DOUBLE       NOT NULL,
 max_in_hz_or_ord    DOUBLE       NOT NULL,
 src_dt_db_site      INTEGER,
 src_dt_db_id        INTEGER,
 src_dt_type_code    INTEGER,
 sp_str_db_site      INTEGER,
 sp_str_db_id        INTEGER,
 sp_stream_id        INTEGER,
 assoc_rpm_in_hz     DOUBLE,
 amplitude           DOUBLE       NOT NULL,
 angle_in_degrees    DOUBLE,
 name                VARCHAR(254),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, ordering_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES 
        meas_event (meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES 
        eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code) REFERENCES 
        post_scaling_type (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code),
    FOREIGN KEY (src_dt_db_site, src_dt_db_id, src_dt_type_code) REFERENCES 
        src_detect_type (src_dt_db_site, src_dt_db_id, src_dt_type_code),
    FOREIGN KEY (sp_str_db_site, sp_str_db_id, sp_stream_id)
        REFERENCES sp_stream (sp_str_db_site, sp_str_db_id, sp_stream_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (freq_or_order in ('F','O'))
 );

// REM #77 -- Measurement Location Signal-processed Single Amplitude 
// REM        Alarm Region Table
// REM
// REM This table will store all low-high alarm regions for signal-processed
// REM frequency or order-limited, single amplitude data at a specified 
// REM measurement location for a site database.
// REM
// REM This table allows every site database to store their own set of
// REM alarm regions for each measurement location/frequency or order region
// REM combination.  In addition, the table stores the history of the 
// REM changes of these alarm regions.  An application may only want the
// REM maximum gmt_alarm_start of a particular region and ignore the 
// REM history of how the alarm changed over time.
// REM
// REM  The interpretation of the 2 data columns:
// REM
// REM       If <current_amplitude> >= min_amplitude AND
// REM          <current_amplitude> <  max_amplitude
// REM       Then alarm region is triggered.
// REM
// REM   NOTE: To create a region which ends at +infinity set the 
// REM         max_amplitude = MAXDOUBLE value.  To create a region
// REM         which starts at -infinity set the min_amplitude to 
// REM         MINDOUBLE value.
// REM
// REM   NOTE: If a system does not track the history of alarm levels, 
// REM         then the gmt_alarm_start field can be set to the earliest
// REM         possible date the alarm could have been created in the database.
// REM
// REM   NOTE: st_loc_hr_delta is the the number of hours +/- GMT
// REM         to calculate the correct local time for the date the
// REM         alarm started.
// REM
// REM   NOTE: If a system does not track the history of alarm levels,
// REM         then the gmt_alarm_start field can be set to the earliest
// REM         possible date the alarm could have been created in the database.
// REM
CREATE TABLE mloc_spa_alrm_rg (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 al_db_site          INTEGER      NOT NULL,
 al_db_id            INTEGER      NOT NULL,
 al_type_code        INTEGER      NOT NULL,
 freq_or_order       CHAR(1)      NOT NULL,
 min_in_hz_or_ord    DOUBLE       NOT NULL,
 max_in_hz_or_ord    DOUBLE       NOT NULL,
 gmt_alarm_start     CHAR(29)     NOT NULL,
 st_loc_hr_delta     SMALLINT,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 pst_sc_db_site      INTEGER      NOT NULL,
 pst_sc_db_id        INTEGER      NOT NULL,
 pst_sc_type_code    INTEGER      NOT NULL,
 src_dt_db_site      INTEGER,
 src_dt_db_id        INTEGER,
 src_dt_type_code    INTEGER,
 min_amplitude       DOUBLE       NOT NULL,
 max_amplitude       DOUBLE       NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (meas_loc_site, meas_loc_id, al_db_site, al_db_id, 
        al_type_code, freq_or_order, min_in_hz_or_ord, max_in_hz_or_ord, 
        gmt_alarm_start),
    FOREIGN KEY (meas_loc_site, meas_loc_id) REFERENCES
        meas_location (meas_loc_site, meas_loc_id),
    FOREIGN KEY (al_db_site, al_db_id, al_type_code) REFERENCES 
        alarm_type (al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES 
        eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code) REFERENCES 
        post_scaling_type (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code),
    FOREIGN KEY (src_dt_db_site, src_dt_db_id, src_dt_type_code) REFERENCES
        src_detect_type (src_dt_db_site, src_dt_db_id, src_dt_type_code),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (freq_or_order in ('F','O'))
 );

// REM #79 -- Signal-Processed Frequency/Order Single Amplitude Data Alarm Table
// REM
// REM This table stores all the alarms triggered by the signal-processed
// REM single amplitudes stored in the SP_AMPL_DATA table. If data is 
// REM available in the Measurement Location Signal-processed Single 
// REM Amplitude Alarm Region Table, then the alarm data in this table can 
// REM be derived and does not need to be stored here.
// REM However, some systems do not send all the alarm region data, and we 
// REM need to store the fact that an alarm was triggered.
// REM
CREATE TABLE sp_ampl_alarm (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           CHAR(29)     NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 al_db_site          INTEGER      NOT NULL,
 al_db_id            INTEGER      NOT NULL,
 al_type_code        INTEGER      NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, ordering_seq,
        al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event, ordering_seq)
        REFERENCES sp_ampl_data (meas_loc_site, meas_loc_id, gmt_event, 
        ordering_seq),
    FOREIGN KEY (al_db_site, al_db_id, al_type_code) REFERENCES 
        alarm_type (al_db_site, al_db_id, al_type_code),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #80 -- Window Type Table
// REM
// REM This table stores different types of FFT and time waveform windows.
// REM The pf_multiplier column is the power factor multiplier for the
// REM window.
// REM
// REM   NOTE: MIMOSA maintains tbe zero (0) site entries in this table.
// REM
CREATE TABLE window_type (
 win_db_site         INTEGER      NOT NULL,
 win_db_id           INTEGER      NOT NULL,
 win_type_code       INTEGER      NOT NULL,
 name                VARCHAR(254) NOT NULL,
 pf_multiplier       DOUBLE       NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (win_db_site, win_db_id, win_type_code),
    FOREIGN KEY (win_db_site, win_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #81 -- Signal-Processed, Real/Complex Linear Frequency/Order FFT Spectrum
// REM        Data Table
// REM
// REM This table will store real-only or complex FFT data which
// REM is related to a frequency or order range which resulted as an output of
// REM a measurement event.
// REM
// REM   NOTE: Spectrum_data is a variable-length binary field, first containing
// REM         4-byte IEEE float real values for each line of resolution in the 
// REM         spectra.  If the complex_yn field = 'Y', then the imaginary
// REM         float values in 4-byte IEEE format follow the set of real
// REM         values.  
// REM
// REM         The IEEE format is:
// REM         
// REM                 --> Low-Order Byte First
// REM                      bits  0-22 --> Mantissa
// REM                      bits 23-30 --> Exponent
// REM                      bit  31    --> Sign
// REM
// REM   NOTE: The bin width = (max_in_hz_or_ord - min_in_hz_or_ord) /
// REM                         resolution_lines
// REM
// REM   NOTE: The frequency/order associated with the first line of the 
// REM         spectrum = min_in_hz_or_ord + bin_width
// REM
// REM   NOTE: The ave_overlap_pct column is an percentage ranging from 
// REM         0 -- 100 of the average overlap percentage used.
// REM
CREATE TABLE sp_fft_data (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           CHAR(29)     NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 pst_sc_db_site      INTEGER      NOT NULL,
 pst_sc_db_id        INTEGER      NOT NULL,
 pst_sc_type_code    INTEGER      NOT NULL,
 freq_or_order       CHAR(1)      NOT NULL,
 min_in_hz_or_ord    DOUBLE       NOT NULL,
 max_in_hz_or_ord    DOUBLE       NOT NULL,
 resolution_lines    INTEGER      NOT NULL,
 win_db_site         INTEGER      NOT NULL,
 win_db_id           INTEGER      NOT NULL,
 win_type_code       INTEGER      NOT NULL,
 ave_db_site         INTEGER,
 ave_db_id           INTEGER,
 ave_type_code       INTEGER,
 ave_wt_db_site      INTEGER,
 ave_wt_db_id        INTEGER,
 ave_wt_type_code    INTEGER,
 ave_sy_db_site      INTEGER,
 ave_sy_db_id        INTEGER,
 ave_sy_type_code    INTEGER,
 ave_overlap_pct     DOUBLE,
 num_of_averages     INTEGER,
 sp_str_db_site      INTEGER,
 sp_str_db_id        INTEGER,
 sp_stream_id        INTEGER,
 assoc_rpm_in_hz     DOUBLE,
 name                VARCHAR(254),
 dc_level            DOUBLE,
 complex_yn          CHAR(1)      NOT NULL,
 spectrum_data       LONG BINARY,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, ordering_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES 
        meas_event (meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES 
        eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code) REFERENCES 
        post_scaling_type (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code),
    FOREIGN KEY (win_db_site, win_db_id, win_type_code) REFERENCES 
        window_type (win_db_site, win_db_id, win_type_code),
    FOREIGN KEY (ave_db_site, ave_db_id, ave_type_code) REFERENCES 
        average_type (ave_db_site, ave_db_id, ave_type_code),
    FOREIGN KEY (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code) REFERENCES 
        ave_weight_type (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code),
    FOREIGN KEY (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code) REFERENCES 
        ave_synch_type (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code),
    FOREIGN KEY (sp_str_db_site, sp_str_db_id, sp_stream_id)
        REFERENCES sp_stream (sp_str_db_site, sp_str_db_id, sp_stream_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (freq_or_order in ('F','O')),
    CHECK (complex_yn in ('Y','N'))
 );

// REM #83 -- Signal-Processed, Real/Complex Linear Time Waveform Data Table
// REM
// REM This table will store real-only or complex time waveform data which 
// REM resulted as an output of a measurement event.  A complex time waveform
// REM is obtained when you have a decimated signal over a certain frequency range.
// REM
// REM   NOTE: Waveform_data is a variable-length binary field, first containing
// REM         4-byte IEEE float real values of length number_of_samples in
// REM         length.  If the complex_yn field = 'Y', then the imaginary
// REM         float values in 4-byte IEEE format follow the real set of values.
// REM
// REM         The IEEE format is:
// REM         
// REM                 --> Low-Order Byte First
// REM                      bits  0-22 --> Mantissa
// REM                      bits 23-30 --> Exponent
// REM                      bit  31    --> Sign
// REM
// REM   NOTE: The off_secs_or_revs column is the delta offset start time
// REM         in seconds or offset number of revolutions from gmt_event 
// REM         time when the sample started.
// REM
// REM   NOTE: The ave_overlap_pct column is an percentage ranging from 
// REM         0 -- 100 of the average overlap percentage used.
// REM
CREATE TABLE sp_time_data (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           CHAR(29)     NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 secs_or_revs        CHAR(1)      NOT NULL,
 off_secs_or_revs    DOUBLE       NOT NULL,
 max_secs_or_revs    DOUBLE       NOT NULL,
 number_of_samples   DOUBLE       NOT NULL,
 win_db_site         INTEGER      NOT NULL,
 win_db_id           INTEGER      NOT NULL,
 win_type_code       INTEGER      NOT NULL,
 ave_db_site         INTEGER,
 ave_db_id           INTEGER,
 ave_type_code       INTEGER,
 ave_wt_db_site      INTEGER,
 ave_wt_db_id        INTEGER,
 ave_wt_type_code    INTEGER,
 ave_sy_db_site      INTEGER,
 ave_sy_db_id        INTEGER,
 ave_sy_type_code    INTEGER,
 ave_overlap_pct     DOUBLE,
 num_of_averages     INTEGER,
 sp_str_db_site      INTEGER,
 sp_str_db_id        INTEGER,
 sp_stream_id        INTEGER,
 assoc_rpm_in_hz     DOUBLE,
 name                VARCHAR(254),
 complex_yn          CHAR(1)      NOT NULL,
 waveform_data       LONG BINARY,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, ordering_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES 
        meas_event (meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES 
        eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (win_db_site, win_db_id, win_type_code) REFERENCES 
        window_type (win_db_site, win_db_id, win_type_code),
    FOREIGN KEY (ave_db_site, ave_db_id, ave_type_code) REFERENCES 
        average_type (ave_db_site, ave_db_id, ave_type_code),
    FOREIGN KEY (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code) REFERENCES 
        ave_weight_type (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code),
    FOREIGN KEY (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code) REFERENCES 
        ave_synch_type (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code),
    FOREIGN KEY (sp_str_db_site, sp_str_db_id, sp_stream_id)
        REFERENCES sp_stream (sp_str_db_site, sp_str_db_id, sp_stream_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (secs_or_revs in ('S','R')),
    CHECK (complex_yn in ('Y','N'))
 );

// REM #85 -- Signal-Processed, Real Linear Constant Percentage Band Spectrum 
// REM        Table
// REM
// REM This table will store real CPB spectrum data which resulted as an 
// REM output of a measurement event.
// REM
// REM   NOTE: Spectrum_data is a variable-length binary field, containing
// REM         4-byte IEEE float real values for each band in the 
// REM         spectra.  The IEEE format is:
// REM         
// REM                 --> Low-Order Byte First
// REM                      bits  0-22 --> Mantissa
// REM                      bits 23-30 --> Exponent
// REM                      bit  31    --> Sign
// REM
// REM The width_pct_or_oct column stores a "P" for percent band width (0-100)
// REM or an "O" for octave width associated with the band_width column.
// REM
// REM The field center_in_hz_1bd is the first band's center frequency in
// REM hertz.
// REM
CREATE TABLE sp_cpb_data (
 meas_loc_site       INTEGER      NOT NULL,
 meas_loc_id         INTEGER      NOT NULL,
 gmt_event           CHAR(29)     NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 eu_db_site          INTEGER      NOT NULL,
 eu_db_id            INTEGER      NOT NULL,
 eu_type_code        INTEGER      NOT NULL,
 pst_sc_db_site      INTEGER      NOT NULL,
 pst_sc_db_id        INTEGER      NOT NULL,
 pst_sc_type_code    INTEGER      NOT NULL,
 number_of_bands     INTEGER      NOT NULL,
 center_in_hz_1bd    DOUBLE       NOT NULL,
 width_pct_or_oct    CHAR(1)      NOT NULL,
 band_width          DOUBLE       NOT NULL,
 ave_db_site         INTEGER,
 ave_db_id           INTEGER,
 ave_type_code       INTEGER,
 ave_wt_db_site      INTEGER,
 ave_wt_db_id        INTEGER,
 ave_wt_type_code    INTEGER,
 ave_sy_db_site      INTEGER,
 ave_sy_db_id        INTEGER,
 ave_sy_type_code    INTEGER,
 ave_overlap_pct     DOUBLE,
 num_of_averages     INTEGER,
 sp_str_db_site      INTEGER,
 sp_str_db_id        INTEGER,
 sp_stream_id        INTEGER,
 assoc_rpm_in_hz     DOUBLE,
 name                VARCHAR(254),
 spectrum_data       LONG BINARY,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (meas_loc_site, meas_loc_id, gmt_event, ordering_seq),
    FOREIGN KEY (meas_loc_site, meas_loc_id, gmt_event) REFERENCES 
        meas_event (meas_loc_site, meas_loc_id, gmt_event),
    FOREIGN KEY (eu_db_site, eu_db_id, eu_type_code) REFERENCES 
        eng_unit_type (eu_db_site, eu_db_id, eu_type_code),
    FOREIGN KEY (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code) REFERENCES 
        post_scaling_type (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code),
    FOREIGN KEY (ave_db_site, ave_db_id, ave_type_code) REFERENCES 
        average_type (ave_db_site, ave_db_id, ave_type_code),
    FOREIGN KEY (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code) REFERENCES 
        ave_weight_type (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code),
    FOREIGN KEY (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code) REFERENCES 
        ave_synch_type (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code),
    FOREIGN KEY (sp_str_db_site, sp_str_db_id, sp_stream_id)
        REFERENCES sp_stream (sp_str_db_site, sp_str_db_id, sp_stream_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (width_pct_or_oct in ('P','O'))
 );

// REM #89 -- Collection Setup Parameters for Signal-processed Frequency/Order
// REM        Single Amplitude/Vector Data Table
// REM
// REM This table stores the setup parameters used to capture frequency/order
// REM single amplitudes (or vectors) for a given database.  These setup id's
// REM can then be referenced in the MLOC_ULIST_SP_AMPL table to associate the 
// REM ordered list's measurement location unit with the signal processing 
// REM parameters needed to capture the unit in a specified manner.
// REM
// REM
CREATE TABLE sp_ampl_setup (
 spa_setup_db_site   INTEGER      NOT NULL,
 spa_setup_db_id     INTEGER      NOT NULL,
 spa_setup_id        INTEGER      NOT NULL,
 pst_sc_db_site      INTEGER      NOT NULL,
 pst_sc_db_id        INTEGER      NOT NULL,
 pst_sc_type_code    INTEGER      NOT NULL,
 freq_or_order       CHAR(1)      NOT NULL,
 min_in_hz_or_ord    DOUBLE       NOT NULL,
 max_in_hz_or_ord    DOUBLE       NOT NULL,
 src_dt_db_site      INTEGER,
 src_dt_db_id        INTEGER,
 src_dt_type_code    INTEGER,
 sp_str_db_site      INTEGER,
 sp_str_db_id        INTEGER,
 sp_stream_id        INTEGER,
 name                VARCHAR(254),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (spa_setup_db_site, spa_setup_db_id, spa_setup_id),
    FOREIGN KEY (spa_setup_db_site, spa_setup_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code) REFERENCES 
        post_scaling_type (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code),
    FOREIGN KEY (src_dt_db_site, src_dt_db_id, src_dt_type_code) REFERENCES 
        src_detect_type (src_dt_db_site, src_dt_db_id, src_dt_type_code),
    FOREIGN KEY (sp_str_db_site, sp_str_db_id, sp_stream_id)
        REFERENCES sp_stream (sp_str_db_site, sp_str_db_id, sp_stream_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (freq_or_order in ('F','O'))
 );

// REM #90 -- Collection Setup Parameters for Signal-processed Real/Complex 
// REM        Linear Frequency/Order FFT Spectrum Data Table
// REM
// REM This table stores the setup parameters used to capture real/complex
// REM linear frequency/order FFT spectrum data for a given database.  These 
// REM setup id's can then be referenced in the MLOC_ULIST_SP_FFT table 
// REM to associate the ordered list's measurement location unit with the 
// REM signal processing parameters needed to capture the unit in a 
// REM specified manner.
// REM
// REM
CREATE TABLE sp_fft_setup (
 spf_setup_db_site   INTEGER      NOT NULL,
 spf_setup_db_id     INTEGER      NOT NULL,
 spf_setup_id        INTEGER      NOT NULL,
 pst_sc_db_site      INTEGER      NOT NULL,
 pst_sc_db_id        INTEGER      NOT NULL,
 pst_sc_type_code    INTEGER      NOT NULL,
 freq_or_order       CHAR(1)      NOT NULL,
 min_in_hz_or_ord    DOUBLE       NOT NULL,
 max_in_hz_or_ord    DOUBLE       NOT NULL,
 resolution_lines    INTEGER      NOT NULL,
 win_db_site         INTEGER      NOT NULL,
 win_db_id           INTEGER      NOT NULL,
 win_type_code       INTEGER      NOT NULL,
 ave_db_site         INTEGER,
 ave_db_id           INTEGER,
 ave_type_code       INTEGER,
 ave_wt_db_site      INTEGER,
 ave_wt_db_id        INTEGER,
 ave_wt_type_code    INTEGER,
 ave_sy_db_site      INTEGER,
 ave_sy_db_id        INTEGER,
 ave_sy_type_code    INTEGER,
 ave_overlap_pct     DOUBLE,
 num_of_averages     INTEGER,
 sp_str_db_site      INTEGER,
 sp_str_db_id        INTEGER,
 sp_stream_id        INTEGER,
 complex_yn          CHAR(1)      NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (spf_setup_db_site, spf_setup_db_id, spf_setup_id),
    FOREIGN KEY (spf_setup_db_site, spf_setup_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code) REFERENCES 
        post_scaling_type (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code),
    FOREIGN KEY (win_db_site, win_db_id, win_type_code) REFERENCES 
        window_type (win_db_site, win_db_id, win_type_code),
    FOREIGN KEY (ave_db_site, ave_db_id, ave_type_code) REFERENCES 
        average_type (ave_db_site, ave_db_id, ave_type_code),
    FOREIGN KEY (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code) REFERENCES 
        ave_weight_type (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code),
    FOREIGN KEY (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code) REFERENCES 
        ave_synch_type (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code),
    FOREIGN KEY (sp_str_db_site, sp_str_db_id, sp_stream_id)
        REFERENCES sp_stream (sp_str_db_site, sp_str_db_id, sp_stream_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (freq_or_order in ('F','O')),
    CHECK (complex_yn in ('Y','N'))
 );

// REM #91 -- Collection Setup Parameters for Signal-processed Real/Complex 
// REM        Linear Time Waveform Data Table
// REM
// REM This table stores the setup parameters used to capture real/complex
// REM linear time waveform data for a given database.  These 
// REM setup id's can then be referenced in the MLOC_ULIST_SP_TIME table 
// REM to associate the ordered list's measurement location unit with the 
// REM signal processing parameters needed to capture the unit in a 
// REM specified manner.
// REM
// REM
CREATE TABLE sp_time_setup (
 spt_setup_db_site   INTEGER      NOT NULL,
 spt_setup_db_id     INTEGER      NOT NULL,
 spt_setup_id        INTEGER      NOT NULL,
 secs_or_revs        CHAR(1)      NOT NULL,
 off_secs_or_revs    DOUBLE       NOT NULL,
 max_secs_or_revs    DOUBLE       NOT NULL,
 number_of_samples   DOUBLE       NOT NULL,
 win_db_site         INTEGER      NOT NULL,
 win_db_id           INTEGER      NOT NULL,
 win_type_code       INTEGER      NOT NULL,
 ave_db_site         INTEGER,
 ave_db_id           INTEGER,
 ave_type_code       INTEGER,
 ave_wt_db_site      INTEGER,
 ave_wt_db_id        INTEGER,
 ave_wt_type_code    INTEGER,
 ave_sy_db_site      INTEGER,
 ave_sy_db_id        INTEGER,
 ave_sy_type_code    INTEGER,
 ave_overlap_pct     DOUBLE,
 num_of_averages     INTEGER,
 sp_str_db_site      INTEGER,
 sp_str_db_id        INTEGER,
 sp_stream_id        INTEGER,
 complex_yn          CHAR(1)      NOT NULL,
 name                VARCHAR(254),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (spt_setup_db_site, spt_setup_db_id, spt_setup_id),
    FOREIGN KEY (spt_setup_db_site, spt_setup_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (win_db_site, win_db_id, win_type_code) REFERENCES 
        window_type (win_db_site, win_db_id, win_type_code),
    FOREIGN KEY (ave_db_site, ave_db_id, ave_type_code) REFERENCES 
        average_type (ave_db_site, ave_db_id, ave_type_code),
    FOREIGN KEY (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code) REFERENCES 
        ave_weight_type (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code),
    FOREIGN KEY (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code) REFERENCES 
        ave_synch_type (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code),
    FOREIGN KEY (sp_str_db_site, sp_str_db_id, sp_stream_id)
        REFERENCES sp_stream (sp_str_db_site, sp_str_db_id, sp_stream_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (secs_or_revs in ('S','R')),
    CHECK (complex_yn in ('Y','N'))
 );

// REM #92 -- Collection Setup Parameters for Signal-processed Real Linear 
// REM        Constant Percentage Band Data Table
// REM
// REM This table stores the setup parameters used to capture real CPB
// REM spectrum data for a given database.  These setup id's can then be 
// REM referenced in the MLOC_ULIST_SP_CPB table to associate the ordered 
// REM list's measurement location unit with the  signal processing 
// REM parameters needed to capture the unit in a specified manner.
// REM
// REM
CREATE TABLE sp_cpb_setup (
 spc_setup_db_site   INTEGER      NOT NULL,
 spc_setup_db_id     INTEGER      NOT NULL,
 spc_setup_id        INTEGER      NOT NULL,
 pst_sc_db_site      INTEGER      NOT NULL,
 pst_sc_db_id        INTEGER      NOT NULL,
 pst_sc_type_code    INTEGER      NOT NULL,
 number_of_bands     INTEGER      NOT NULL,
 center_in_hz_1bd    DOUBLE       NOT NULL,
 width_pct_or_oct    CHAR(1)      NOT NULL,
 band_width          DOUBLE       NOT NULL,
 ave_db_site         INTEGER,
 ave_db_id           INTEGER,
 ave_type_code       INTEGER,
 ave_wt_db_site      INTEGER,
 ave_wt_db_id        INTEGER,
 ave_wt_type_code    INTEGER,
 ave_sy_db_site      INTEGER,
 ave_sy_db_id        INTEGER,
 ave_sy_type_code    INTEGER,
 ave_overlap_pct     DOUBLE,
 num_of_averages     INTEGER,
 sp_str_db_site      INTEGER,
 sp_str_db_id        INTEGER,
 sp_stream_id        INTEGER,
 name                VARCHAR(254),
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (spc_setup_db_site, spc_setup_db_id, spc_setup_id),
    FOREIGN KEY (spc_setup_db_site, spc_setup_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code) REFERENCES 
        post_scaling_type (pst_sc_db_site, pst_sc_db_id, pst_sc_type_code),
    FOREIGN KEY (ave_db_site, ave_db_id, ave_type_code) REFERENCES 
        average_type (ave_db_site, ave_db_id, ave_type_code),
    FOREIGN KEY (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code) REFERENCES 
        ave_weight_type (ave_wt_db_site, ave_wt_db_id, ave_wt_type_code),
    FOREIGN KEY (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code) REFERENCES 
        ave_synch_type (ave_sy_db_site, ave_sy_db_id, ave_sy_type_code),
    FOREIGN KEY (sp_str_db_site, sp_str_db_id, sp_stream_id)
        REFERENCES sp_stream (sp_str_db_site, sp_str_db_id, sp_stream_id),
    FOREIGN KEY site_db (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod),
    CHECK (width_pct_or_oct in ('P','O'))
 );

// REM #93 -- Collection Setup Parameters Needed to Collect Amplitude Data 
// REM        in the Ordered List of Eng. Units at Measurement Locations Table
// REM
// REM This table stores the associated collection setup parameter to be used
// REM to capture amplitude data for the engineering unit referenced in the 
// REM ordered list measurement location unit table. 
// REM
// REM
CREATE TABLE mloc_ulist_sp_ampl (
 ord_list_db_site    INTEGER      NOT NULL,
 ord_list_db_id      INTEGER      NOT NULL,
 ord_list_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 channel_number      INTEGER      NOT NULL,
 spa_setup_db_site   INTEGER      NOT NULL,
 spa_setup_db_id     INTEGER      NOT NULL,
 spa_setup_id        INTEGER      NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq,
        channel_number, spa_setup_db_site, spa_setup_db_id, spa_setup_id),
    FOREIGN KEY (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq,
        channel_number) REFERENCES mloc_unit_list (ord_list_db_site, 
        ord_list_db_id, ord_list_id, ordering_seq, channel_number),
    FOREIGN KEY (spa_setup_db_site, spa_setup_db_id, spa_setup_id) REFERENCES
        sp_ampl_setup (spa_setup_db_site, spa_setup_db_id, spa_setup_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #94 -- Collection Setup Parameters Needed to Collect FFT Spectrum Data 
// REM        in the Ordered List of Eng. Units at Measurement Locations Table
// REM
// REM This table stores the associated collection setup parameter to be used
// REM to capture FFT spectrum data for the engineering unit referenced in the 
// REM ordered list measurement location unit table. 
// REM
// REM
CREATE TABLE mloc_ulist_sp_fft (
 ord_list_db_site    INTEGER      NOT NULL,
 ord_list_db_id      INTEGER      NOT NULL,
 ord_list_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 channel_number      INTEGER      NOT NULL,
 spf_setup_db_site   INTEGER      NOT NULL,
 spf_setup_db_id     INTEGER      NOT NULL,
 spf_setup_id        INTEGER      NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq,
        channel_number, spf_setup_db_site, spf_setup_db_id, spf_setup_id),
    FOREIGN KEY (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq,
        channel_number) REFERENCES mloc_unit_list (ord_list_db_site, 
        ord_list_db_id, ord_list_id, ordering_seq, channel_number),
    FOREIGN KEY (spf_setup_db_site, spf_setup_db_id, spf_setup_id) REFERENCES
        sp_fft_setup (spf_setup_db_site, spf_setup_db_id, spf_setup_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #95 -- Collection Setup Parameters Needed to Collect Time Waveform Data 
// REM        in the Ordered List of Eng. Units at Measurement Locations Table
// REM
// REM This table stores the associated collection setup parameter to be used
// REM to capture time waveform data for the engineering unit referenced in the 
// REM ordered list measurement location unit table. 
// REM
// REM
CREATE TABLE mloc_ulist_sp_time (
 ord_list_db_site    INTEGER      NOT NULL,
 ord_list_db_id      INTEGER      NOT NULL,
 ord_list_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 channel_number      INTEGER      NOT NULL,
 spt_setup_db_site   INTEGER      NOT NULL,
 spt_setup_db_id     INTEGER      NOT NULL,
 spt_setup_id        INTEGER      NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq,
        channel_number, spt_setup_db_site, spt_setup_db_id, spt_setup_id),
    FOREIGN KEY (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq,
        channel_number) REFERENCES mloc_unit_list (ord_list_db_site, 
        ord_list_db_id, ord_list_id, ordering_seq, channel_number),
    FOREIGN KEY (spt_setup_db_site, spt_setup_db_id, spt_setup_id) REFERENCES
        sp_time_setup (spt_setup_db_site, spt_setup_db_id, spt_setup_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );

// REM #96 -- Collection Setup Parameters Needed to Collect CPB Spectrum Data 
// REM        in the Ordered List of Eng. Units at Measurement Locations Table
// REM
// REM This table stores the associated collection setup parameter to be used
// REM to capture CPB spectrum data for the engineering unit referenced in the 
// REM ordered list measurement location unit table. 
// REM
// REM
CREATE TABLE mloc_ulist_sp_cpb (
 ord_list_db_site    INTEGER      NOT NULL,
 ord_list_db_id      INTEGER      NOT NULL,
 ord_list_id         INTEGER      NOT NULL,
 ordering_seq        INTEGER      NOT NULL,
 channel_number      INTEGER      NOT NULL,
 spc_setup_db_site   INTEGER      NOT NULL,
 spc_setup_db_id     INTEGER      NOT NULL,
 spc_setup_id        INTEGER      NOT NULL,
 gmt_last_updated    CHAR(29)     NOT NULL,
 last_upd_db_site    INTEGER      NOT NULL,
 last_upd_db_id      INTEGER      NOT NULL,
 rstat_type_code     SMALLINT     NOT NULL,
    PRIMARY KEY (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq,
        channel_number, spc_setup_db_site, spc_setup_db_id, spc_setup_id),
    FOREIGN KEY (ord_list_db_site, ord_list_db_id, ord_list_id, ordering_seq,
        channel_number) REFERENCES mloc_unit_list (ord_list_db_site, 
        ord_list_db_id, ord_list_id, ordering_seq, channel_number),
    FOREIGN KEY (spc_setup_db_site, spc_setup_db_id, spc_setup_id) REFERENCES
        sp_cpb_setup (spc_setup_db_site, spc_setup_db_id, spc_setup_id),
    FOREIGN KEY (last_upd_db_site, last_upd_db_id) REFERENCES 
        site_database (db_site, db_id),
    FOREIGN KEY (rstat_type_code) REFERENCES row_status_type (rstat_type_cod)
 );
